import base64
import datetime
import hashlib
import json
import os
import random
import socket
import time
from io import BytesIO
from pathlib import Path
from typing import Optional

import qrcode
from Crypto.Cipher import PKCS1_v1_5
from Crypto.PublicKey import RSA
from PIL import Image, ImageDraw, ImageFont
from httpx import AsyncClient
from nonebot import logger, get_driver, on_command
from nonebot.adapters.onebot.v11 import MessageEvent
from nonebot.params import ArgStr
from nonebot.permission import SUPERUSER
from pydantic import BaseModel

from . import dxx, path, rule
from ..models.accuont import User
from ..models.dxx import Area, Answer, Resource

USERDATA = path.DATABASE_PATH / "users.json"


class UserModel(BaseModel):
    id: int = None
    """用户ID"""
    time: int = None
    """添加时间戳"""
    self_id: int = None
    """BOT ID"""
    user_id: int = None
    """用户ID"""
    password: str = None
    """登录密码，用于登录web端"""
    group_id: int = None
    """通知群号"""
    name: str = None
    """姓名"""
    gender: str = None
    """性别"""
    mobile: str = None
    """手机号"""
    area: str = None
    """地区"""
    leader: int = None
    """团支书ID"""
    openid: str = None
    """微信认证ID"""
    dxx_id: str = None
    """大学习用户id,nid或uid"""
    university_type: str = None
    """学校类型"""
    university_id: str = None
    """学校id"""
    university: str = None
    """学校名称"""
    college_id: str = None
    """学院id"""
    college: str = None
    """学院名称"""
    organization_id: str = None
    """团支部id"""
    organization: str = None
    """团支部名称"""
    token: str = None
    """提交需要的token"""
    cookie: str = None
    """提交要用的cookie"""
    catalogue: str = None
    """提交期数"""
    auto_submit: bool = True
    """自动提交状态"""
    commit_time: int = None
    """提交时间"""


SUPERS = get_driver().config.superusers
AREA = [
    {
        "area": "湖北",
        "host": "cp.fjg360.cn",
        "referer": None,
        "origin": None,
        "url": "https://h5.cyol.com/special/weixin/sign.json",
        "status": True,
        "catalogue": None
    },
    {
        "area": "江西",
        "host": "www.jxqingtuan.cn",
        "referer": "http://www.jxqingtuan.cn/html/h5_index.html?&accessToken=",
        "origin": "http://www.jxqingtuan.cn",
        "url": "http://www.jxqingtuan.cn/pub/vol/volClass/index?userId=4363431",
        "status": True,
        "catalogue": None
    },
    {
        "area": "浙江",
        "host": "qczj.h5yunban.com",
        "referer": None,
        "origin": None,
        "url": "https://qczj.h5yunban.com/qczj-youth-learning/cgi-bin/common-api/course/current?accessToken=",
        "status": True,
        "catalogue": None
    },
    {
        "area": "上海",
        "host": "qcsh.h5yunban.com",
        "referer": None,
        "origin": None,
        "url": "https://qcsh.h5yunban.com/youth-learning/cgi-bin/user-api/course/join?accessToken=",
        "status": True,
        "catalogue": None
    },
    {
        "area": "安徽",
        "host": "dxx.ahyouth.org.cn",
        "referer": "http://dxx.ahyouth.org.cn/",
        "origin": "http://dxx.ahyouth.org.cn",
        "url": "http://dxx.ahyouth.org.cn/api/hidtoryList",
        "status": True,
        "catalogue": None
    },
    {
        "area": "四川",
        "host": "dxx.scyol.com",
        "referer": "http://scyol.com/v_prod6.02/",
        "origin": "http://scyol.com",
        "url": "https://dxx.scyol.com/api/student/commit",
        "status": True,
        "catalogue": None
    },
    {
        "area": "山东",
        "host": "qndxx.youth54.cn",
        "referer": "http://qndxx.youth54.cn/SmartLA/dxx.w?method=pageSdtwdt",
        "origin": "http://qndxx.youth54.cn",
        "url": "http://qndxx.youth54.cn/SmartLA/dxxjfgl.w?method=getNewestVersionInfo&openid=",
        "status": True,
        "catalogue": None
    },
    {
        "area": "重庆",
        "host": "qndxx.cqyouths.com",
        "referer": None,
        "origin": "http://qndxx.cqyouths.com",
        "url": "http://qndxx.cqyouths.com/new_course.json?time=",
        "status": True,
        "catalogue": None
    },
    {
        "area": "吉林",
        "host": "jqfy.jl54.org",
        "referer": None,
        "origin": "http://jqfy.jl54.org/jltw/wechat",
        "url": "http://jqfy.jl54.org/jltw/wechat",
        "status": True,
        "catalogue": None
    },
    {
        "area": "广东",
        "host": "tuanapi.12355.net",
        "referer": None,
        "origin": "https://tuan.12355.net",
        "url": "https://youthstudy.12355.net/saomah5/api/young/chapter/new",
        "status": True,
        "catalogue": None
    },
    {
        "area": "北京",
        "host": "m.bjyouth.net",
        "referer": None,
        "origin": "https://m.bjyouth.net",
        "url": "https://m.bjyouth.net/dxx/index",
        "status": True,
        "catalogue": None
    },
    {
        "area": "天津",
        "host": "admin.ddy.tjyun.com",
        "referer": None,
        "origin": "https://admin.ddy.tjyun.com",
        "url": "http://admin.ddy.tjyun.com/zm/jump/1",
        "status": True,
        "catalogue": None
    },
    {
        "area": "陕西",
        "host": "api.sxgqt.org.cn",
        "referer": None,
        "origin": "https://h5.sxgqt.org.cn",
        "url": "https://api.sxgqt.org.cn/h5sxapiv2/study/studyLink",
        "status": True,
        "catalogue": None
    },
]
RESOURCE = [
    {
        "name": "MiSans-Light.ttf",
        "url": "",
        "type": "字体",
        "size": "7.6 M"
    }, {
        "name": "answer.png",
        "url": "",
        "type": "答案背景",
        "size": "860.5 K"
    },
    {
        "name": "backgroud1.jpg",
        "url": "",
        "type": "完成截图背景",
        "size": "51.0 K"
    }, {
        "name": "backgroud2.jpg",
        "url": "",
        "type": "完成截图背景",
        "size": "50.9 K"
    }, {
        "name": "backgroud3.jpg",
        "url": "",
        "type": "完成截图背景",
        "size": "50.9 K"
    }, {
        "name": "backgroud4.jpg",
        "url": "",
        "type": "完成截图背景",
        "size": "50.7 K"
    }, {
        "name": "backgroud5.jpg",
        "url": "",
        "type": "完成截图背景",
        "size": "50.4 K"
    }
]

export_data = on_command("export_data", aliases={"导出用户数据", "导出数据"}, priority=50, permission=SUPERUSER,
                         rule=rule.must_command)
update_users = on_command("update_user", aliases={"更新用户数据", "刷新用户数据"}, priority=50, permission=SUPERUSER,
                          rule=rule.must_command)
update_resource = on_command("update_resource", aliases={"更新资源数据", "刷新资源数据"}, priority=50,
                             permission=SUPERUSER, rule=rule.must_command)


@update_resource.got(key="msg", prompt="是否刷新资源数据库信息？（是|否）")
async def update_resource_(msg: str = ArgStr("msg")) -> None:
    if msg not in ["是", "yes", "Y", "y", "YES", "true"]:
        await update_resource.finish(message="操作取消(*^▽^*)", at_sender=True, reply_message=True)
    else:
        await update_resource.send("资源重新载入中（请等待1分钟左右）······", at_sender=True, reply_message=True)
        await Resource.all().delete()
        await resource_init()
        await update_resource.finish(message="资源数据载入成功(^_−)☆", at_sender=True, reply_message=True)


@export_data.got(key="msg", prompt="是否导出用户数据至TeenStudy目录？（是|否）")
async def export_user(event: MessageEvent, msg: str = ArgStr("msg")) -> None:
    self_id = event.self_id
    if msg not in ["是", "yes", "Y", "y", "YES", "true"]:
        await export_data.finish(message="操作取消(*^▽^*)", at_sender=True, reply_message=True)
    else:
        result = await User.all().values()
        user_list = []
        for item in result:
            data = UserModel().dict()
            item["self_id"] = self_id
            data.update(**item)
            user_list.append(data)
        with open(USERDATA, "w", encoding="utf-8") as w:
            json.dump(user_list, w, indent=4, ensure_ascii=False)
        await export_data.finish(message="用户数据成功导出至TeenStudy目录(*^▽^*)", at_sender=True,
                                 reply_message=True)


@update_users.handle()
async def update_user() -> None:
    if not Path(USERDATA).exists():
        await update_users.finish(
            message="更新失败，没有找到可导入用户数据文件，请确保TeeStudy数据目录下存有用户数据文件╮(╯﹏╰）╭",
            at_sender=True, reply_message=True)


@update_users.got(key="msg", prompt="是否覆盖更新用户数据?（是|否）")
async def update_user() -> None:
    with open(USERDATA, "r", encoding="utf-8") as f:
        data_obj = json.load(f)
    await User.all().delete()
    for item in data_obj:
        data = UserModel().dict()
        data.update(**item)
        await User.create(**data)
    await update_users.finish(message="用户数据更新完成(*^▽^*)", at_sender=True, reply_message=True)


async def plugin_init():
    for item in AREA:
        if await Area.filter(area=item['area']).count():
            continue
        else:
            await Area.create(
                time=time.time(),
                area=item['area'],
                host=item['host'],
                referer=item['referer'],
                origin=item['origin'],
                url=item['url'],
                status=item['status'],
                catalogue=item['catalogue']
            )


async def admin_init():
    try:
        superuser = int(list(get_driver().config.superusers)[0])
    except AttributeError:
        superuser = -1
        logger.error("请配置好超管账号，之后重启nonebot2")
    try:
        ip = get_driver().config.dxx_ip
    except AttributeError:
        s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
        s.connect(('114.114.114.114', 12345))
        ip = s.getsockname()[0]
    result = path.getConfig()
    if result["DXX_IP"] == ip and result["SUPERUSER"] == superuser:
        return
    else:
        headers = {
            "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/110.0.0.0 Safari/537.36 Edg/110.0.1587.41"
        }
        try:
            logger.opt(colors=True).info(
                f'<u><y>[大学习数据库]</y></u><g>加载配置公网IP</g>')
            ip = get_driver().config.dxx_ip
            logger.opt(colors=True).info(
                f'<u><y>[大学习数据库]</y></u><g>加载配置公网IP成功，启动检测公网IP访问状态</g>ip:<m>{ip}</m>')
        except AttributeError:
            ip = ''
            logger.opt(colors=True).info(
                f'<u><y>[大学习数据库]</y></u><g>加载配置IP失败，未检测到配置ip，启动自动获取公网IP</g>')
        if not ip:
            async with AsyncClient(headers=headers) as client:
                response = await client.get("http://ip.42.pl/raw")
            if response.status_code == 200:
                ip = response.text.strip()
                logger.opt(colors=True).info(
                    f'<u><y>[大学习数据库]</y></u><g>自动获取公网IP成功</g>ip:<m>{ip}</m>')
            else:
                ip = ""
                logger.opt(colors=True).warning(
                    f'<u><y>[大学习数据库]</y></u><g>自动获取公网IP失败，将自动配置局域网IP，请手动在.env.prod文件中配置公网IP，配置格式：DXX_IP="您的公网IP"</g>')
        if not ip:
            s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
            s.connect(('114.114.114.114', 12345))
            ip = s.getsockname()[0]
            logger.opt(colors=True).success(
                f'<u><y>[大学习提交 Web UI]</y></u><g>配置局域网IP成功</g>，局域网访问地址为:<m>http://{ip}:{get_driver().config.port}/TeenStudy/login</m>')
        data = {
            "TOKEN_TIME": 30,
            "SUPERUSER": int(list(SUPERS)[0]),
            "KEY": "d82ffad91168fb324ab6ebc2bed8dacd43f5af8e34ad0d1b75d83a0aff966a06",
            "ALGORITHM": "HS256",
            "PASSWORD": await to_hash("admin"),
            "DXX_IP": ip,
            "DXX_PORT": get_driver().config.port
        }
        path.saveConfig(data=data)


async def resource_init():
    base_file_path = os.path.dirname(__file__)[:-5] + "resource/"
    logger.opt(colors=True).info("<u><y>[大学习数据库]</y></u><g>➤➤➤➤➤检查资源数据✔✔✔✔✔</g>")
    for item in RESOURCE:
        if not await Resource.filter(name=item['name']).count():
            try:
                with open(base_file_path + item['name'], 'rb') as r:
                    content = r.read()
                await Resource.create(
                    time=time.time(),
                    name=item['name'],
                    type=item['type'],
                    url=item['url'],
                    size=item['size'],
                    file=content
                )
                logger.opt(colors=True).success(
                    f"<u><y>[大学习数据库]</y></u> <m>{item['type']}-{item['name']}</m> <g>更新成功!</g>")
            except Exception as e:
                logger.success(e)
                continue
    logger.opt(colors=True).success("<u><y>[大学习数据库]</y></u><g>➤➤➤➤➤资源数据更新完成✔✔✔✔✔</g>")


async def get_end_pic(id: int):
    font_data = await Resource.filter(type="字体").values()
    answer = await Answer.filter(id=id).order_by('time').values()
    title = '"青年大学习"' + answer[-1]["catalogue"]
    backgrouds = await Resource.filter(type="完成截图背景").values()
    bg_img = Image.open(BytesIO(backgrouds[random.randint(0, 4)]['file']))
    end_img = Image.open(BytesIO(answer[-1]['cover']))
    end_img = end_img.resize((1080, 2200), Image.BILINEAR)
    font = ImageFont.truetype(BytesIO(font_data[0]['file']), 45)
    img = Image.new('RGB', (end_img.width, bg_img.height), (255, 255, 255))
    draw = ImageDraw.Draw(img)
    img.paste(bg_img)
    time = (datetime.datetime.now() + datetime.timedelta(minutes=random.randint(2, 5))).strftime('%H:%M')
    draw.text((120, 30), text=time, font=font, fill='black')
    draw.text((1080 / 2 - (len(title) / 2) * 30, 130), text=title, font=font, fill='black')
    img.paste(end_img, (0, 200))
    buf = BytesIO()
    img.save(buf, format="PNG")
    base64_str = base64.b64encode(buf.getbuffer()).decode()
    content = "base64://" + base64_str
    return content


async def get_answer_pic():
    font_data = await Resource.filter(type="字体").values()
    answer_result = await Answer.all().order_by('time').values()
    backgrouds = await Resource.filter(type="答案背景").values()
    title = answer_result[-1]["catalogue"]
    answer = answer_result[-1]["answer"]
    start_time = datetime.datetime.fromtimestamp(answer_result[-1]['time']).strftime(
        "%Y年%m月%d日 %H:%M:%S")
    end_day = (datetime.datetime.fromtimestamp(answer_result[-1]["time"]) + datetime.timedelta(
        days=7)).strftime("%Y年%m月%d日")
    end_time = f'{end_day} 22:00:00'
    answer_bg = Image.open(BytesIO(backgrouds[0]['file']))
    img = Image.new('RGB', (902, 987), (255, 255, 255))
    img.paste(answer_bg)
    draw = ImageDraw.Draw(img)
    font = ImageFont.truetype(BytesIO(font_data[0]['file']), 55)
    draw.text((20, 20), text='青年大学习主题团课', fill='gold', font=font)
    font = ImageFont.truetype(BytesIO(font_data[0]['file']), 48)
    draw.text((20, 100), text=title, fill='gold', font=font)
    font = ImageFont.truetype(BytesIO(font_data[0]['file']), 40)
    draw.text((20, 180), fill='gold', font=font, text=answer)
    font = ImageFont.truetype(BytesIO(font_data[0]['file']), 40)
    draw.text((410, 550), fill='gold', font=font, text=start_time)
    font = ImageFont.truetype(BytesIO(font_data[0]['file']), 40)
    draw.text((410, 650), fill='gold', font=font, text=end_time)
    font = ImageFont.truetype(BytesIO(font_data[0]['file']), 40)
    draw.text((550, 500), text='开始时间', fill='gold', font=font)
    font = ImageFont.truetype(BytesIO(font_data[0]['file']), 40)
    draw.text((550, 600), text='结束时间', fill='gold', font=font)
    buf = BytesIO()
    img.save(buf, format="PNG")
    base64_str = base64.b64encode(buf.getbuffer()).decode()
    content = "base64://" + base64_str
    return content


async def to_hash(text: str) -> str:
    """
    哈希散列加密
    :param text:待加密文本
    :return: 加密文本
    """
    return hashlib.sha256(text.encode("utf-8")).hexdigest()


async def encrypt(text: str):
    """
    RSA加密
    :param text: 待加密文本
    :return: 加密文本
    """
    public_key = "-----BEGIN PUBLIC KEY-----\nMIGfMA0GCSqGSIb3DQEBAQUAA4GNADCBiQKBgQD5uIDebA2qU746e/NVPiQSBA0Q3J8/G23zfrwMz4qoip1vuKaVZykuMtsAkCJFZhEcmuaOVl8nAor7cz/KZe8ZCNInbXp2kUQNjJiOPwEhkGiVvxvU5V5vCK4mzGZhhawF5cI/pw2GJDSKbXK05YHXVtOAmg17zB1iJf+ie28TbwIDAQAB\n-----END PUBLIC KEY-----"
    rsa_key = RSA.importKey(public_key)
    cipher = PKCS1_v1_5.new(rsa_key)
    cipher_text = base64.b64encode(cipher.encrypt(text.encode()))
    return cipher_text.decode()


async def distribute_area(user_id: int, area: str, catalogue: Optional[str] = None) -> dict:
    if area == "湖北":
        return await dxx.hubei(user_id=user_id, catalogue=catalogue)
    elif area == "江西":
        return await dxx.jiangxi(user_id=user_id, catalogue=catalogue)
    elif area == "浙江":
        return await dxx.zhejiang(user_id=user_id)
    elif area == "上海":
        return await dxx.shanghai(user_id=user_id)
    elif area == "安徽":
        return await dxx.anhui(user_id=user_id)
    elif area == "四川":
        return await dxx.sichuan(user_id=user_id)
    elif area == "山东":
        return await dxx.shandong(user_id=user_id, catalogue=catalogue)
    elif area == "重庆":
        return await dxx.chongqing(user_id=user_id)
    elif area == "吉林":
        return await dxx.jilin(user_id=user_id)
    elif area == "广东":
        return await dxx.guangdong(user_id=user_id)
    elif area == "北京":
        return await dxx.beijing(user_id=user_id)
    elif area == "天津":
        return await dxx.tianjin(user_id=user_id)
    elif area == "陕西":
        return await dxx.shanxi(user_id=user_id, catalogue=catalogue)
    else:
        return {
            "status": 404,
            "msg": "该地区暂未支持！"
        }


async def distribute_area_url(province: str, user_id: int, group_id: int) -> dict:
    config = path.getConfig()
    if province == "湖北":
        province = "hubei"
    elif province == "江西":
        province = "jiangxi"
    elif province == "安徽":
        province = "anhui"
    elif province == "四川":
        province = "sichuan"
    elif province == "山东":
        province = "shandong"
    elif province == "重庆":
        province = "chongqing"
    elif province == "吉林":
        province = "jilin"
    elif province == "广东":
        province = "guangdong"
    elif province == "北京":
        province = "beijing"
    elif province == "天津":
        province = "tianjin"
    elif province == "陕西":
        province = "shanxi"
    data = f"http://{config['DXX_IP']}:{config['DXX_PORT']}/TeenStudy/api/{province}?user_id={user_id}&group_id={group_id}"
    img = qrcode.make(data=data)
    buf = BytesIO()
    img.save(buf, format="PNG")
    base64_str = base64.b64encode(buf.getbuffer()).decode()
    content = "base64://" + base64_str
    return {
        "url": data,
        "content": content
    }


async def get_login_qrcode() -> dict:
    config = path.getConfig()
    data = f'http://{config["DXX_IP"]}:{config["DXX_PORT"]}/TeenStudy/login'
    img = qrcode.make(data=data)
    buf = BytesIO()
    img.save(buf, format="PNG")
    base64_str = base64.b64encode(buf.getbuffer()).decode()
    content = "base64://" + base64_str
    return {
        "url": data,
        "content": content
    }


async def get_qrcode(user_id: int, group_id: int, area: str) -> dict:
    config = path.getConfig()
    if area == "浙江":
        data = f"https://open.weixin.qq.com/connect/oauth2/authorize?appid=wx56b888a1409a2920&redirect_uri=https://wx.yunban.cn/wx/oauthInfoCallback?r_uri=http://{config['DXX_IP']}:{config['DXX_PORT']}/TeenStudy/api/zhejiang/{user_id}/{group_id}&source=common&response_type=code&scope=snsapi_userinfo&state=STATE&component_appid=wx0f0063354bfd3d19&connect_redirect=1"
    else:
        data = f"https://open.weixin.qq.com/connect/oauth2/authorize?appid=wxa693f4127cc93fad&redirect_uri=https://wx.yunban.cn/wx/oauthInfoCallback?r_uri=http://{config['DXX_IP']}:{config['DXX_PORT']}/TeenStudy/api/shanghai/{user_id}/{group_id}&source=common&response_type=code&scope=snsapi_userinfo&state=STATE&component_appid=wx0f0063354bfd3d19&connect_redirect=1"
    img = qrcode.make(data=data)
    buf = BytesIO()
    img.save(buf, format="PNG")
    base64_str = base64.b64encode(buf.getbuffer()).decode()
    content = "base64://" + base64_str
    return {
        "url": data,
        "content": content
    }



import json
from pathlib import Path
from typing import Optional, Union

from nonebot import logger
from pydantic import BaseModel
from tortoise import Tortoise

from ..models import accuont, dxx

# 插件基础数据
DATABASE_PATH = Path().cwd() / 'data' / 'TeenStudy'

DATABASE_PATH.mkdir(parents=True, exist_ok=True)
PATH = DATABASE_PATH / "database.db"
CONFIG_PATH = DATABASE_PATH / "config.json"
DATABASE = {
    'connections': {
        'TeenStudy_database': {
            'engine': 'tortoise.backends.sqlite',
            'credentials': {'file_path': PATH},
        }
    },
    "apps": {
        'TeenStudy_database': {
            'models': [accuont.__name__,
                       dxx.__name__],
            'default_connection': 'TeenStudy_database',
        }
    },
    'use_tz': False,
    'timezone': 'Asia/Shanghai'
}


class Config(BaseModel):
    DXX_IP: str = "127.0.0.1"
    """大学习访问IP"""
    DXX_PORT: int = None
    """大学习访问端口"""
    SUPERUSER: int = None
    """超管账号"""
    KEY: str = "d82ffad91168fb324ab6ebc2bed8dacd43f5af8e34ad0d1b75d83a0aff966a06"
    """大学习秘钥，为64位哈希散列值，用于生成token"""
    ALGORITHM: str = "HS256"
    """加密算法"""
    TOKEN_TIME: int = 30
    """token时效"""
    PASSWORD: str = None
    """后台登录算法"""
    DXX_REMIND: bool = True
    """周一检测更新提醒"""
    DXX_REMIND_HOUR: int = 9
    """大学习更新提醒时间-小时，可填范围：0-23"""
    DXX_REMIND_MINUTE: int = 0
    """大学习更新提醒时间-分钟，可选范围：0-59"""
    POKE_SUBMIT: bool = True
    """戳一戳提交大学习状态"""
    AUTO_SUBMIT: bool = True
    """周一11:30自动提交状态"""
    AUTO_SUBMIT_HOUR: int = 11
    """大学习自动提交时间-小时，可选范围：0-23"""
    AUTO_SUBMIT_MINUTE: int = 30
    """大学习自动提交时间-分钟，可选范围：0-59"""
    URL_STATUS: bool = False
    """是否将二维码转链接发送，默认为False"""


def saveConfig(data: dict) -> bool:
    try:
        config = Config().dict()
        config.update(**data)
        with open(CONFIG_PATH, "w", encoding="utf-8") as w:
            json.dump(config, w, ensure_ascii=False, indent=4)
        return True
    except Exception as e:
        logger.error(e)
        return False


def getConfig() -> dict:
    if not Path(CONFIG_PATH).exists():
        status = saveConfig({
        })
        if status:
            return Config().dict()
    else:
        with open(CONFIG_PATH, "r", encoding="utf-8") as f:
            obj = json.load(f)
        if "URL_STATUS" not in obj.keys():
            obj["URL_STATUS"] = False
            with open(CONFIG_PATH, "w", encoding="utf-8") as w:
                json.dump(obj, w, indent=4, ensure_ascii=False)
        return obj


def register_database(db_name: str, models: str, db_path: Optional[Union[str, Path]]):
    """
    注册数据库
    :param db_name: 数据库名称
    :param models: 数据存储模型
    :param db_path: 数据存储路径
    :return:
    """
    if db_name in DATABASE['connections'] and db_name in DATABASE['apps']:
        DATABASE['apps'][db_name]['models'].append(models)
    else:
        DATABASE['connections'][db_name] = {
            'engine': 'tortoise.backends.sqlite',
            'credentials': {'file_path': db_path},
        }
        DATABASE['apps'][db_name] = {
            'models': [models],
            'default_connection': db_name,
        }


async def connect():
    """
    建立数据库连接
    """
    try:
        await Tortoise.init(DATABASE)
        await Tortoise.generate_schemas()
        logger.opt(colors=True).success('<u><y>[大学习数据库]</y></u><g>➤➤➤➤➤连接成功✔✔✔✔✔</g>')
    except Exception as e:
        logger.opt(colors=True).warning(f'<u><y>[大学习数据库]</y></u><r>➤➤➤➤➤连接失败✘✘✘✘✘:{e}</r>')
        raise e


async def disconnect():
    """
    断开数据库连接
    """
    await Tortoise.close_connections()
    logger.opt(colors=True).success('<u><y>[大学习数据库]</y></u><r>◄◄◄◄◄连接已断开✘✘✘✘✘</r>')



from amis import Page, Divider, Html, Form, InputText, DisplayModeEnum, Alert, LevelEnum

logo = Html(html=f'''
<p align="center">
    <a href="https://github.com/YouthLearning/TeenStudy/">
        <img src="https://img1.imgtp.com/2023/10/06/NChUNeiA.png"
         width="256" height="256" alt="TeenStudy">
    </a>
</p>
<h2 align="center">大学习自动提交</h2>
<div align="center">
    <a href="https://github.com/YouthLearning/TeenStudy" target="_blank">
    Github仓库</a>
    <a href="https://jq.qq.com/?_wv=1027&k=NGFEwXyS" target="_blank">QQ反馈群</a>
    <a href="http://qm.qq.com/cgi-bin/qm/qr?_wv=1027&k=2PQucjirnkHyPjoS1Pkr-ai2aPGToBKm" target="_blank">QQ体验群</a>
</div>

<br>
''')
footer = Html(
    html=f'<div class="p-2 text-center bg-blue-100">Copyright © 2022 - 2023 <a href="https://github.com/YouthLearning/TeenStudy" target="_blank" class="link-secondary">TeenStudy v.0.2.5</a> X<a target="_blank" href="https://github.com/baidu/amis" class="link-secondary" rel="noopener"> amis v.3.4.3</a></div>')
hubei_table = Form(
    title="青春湖北",
    mode=DisplayModeEnum.horizontal,
    api="post:/TeenStudy/api/add",
    redirect="/TeenStudy/login",
    body=[
        InputText(
            label="用户ID",
            description="用户ID，为用户QQ号，无需填写",
            name="user_id",
            value="${user_id}",
            disabled=True
        ),
        InputText(
            label="通知群ID",
            description="通知群号，无需填写",
            name="group_id",
            value="${group_id}",
            disabled=True
        ),
        InputText(
            label="地区",
            description="所处省份",
            name="area",
            value="湖北",
            disabled=True
        ),
        InputText(
            label="登录密码",
            type='input-password',
            description="可不填，默认为用户ID",
            name="password",
            inline=False,
            required=False,
            value="",
            clearable=True,
            maxLength=16
        ),
        InputText(
            label="姓名",
            description="对应青春湖北个人信息页 您的姓名",
            name="name",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=8
        ),
        InputText(
            label="用户编号",
            description="对应青春湖北个人信息页 用户编号",
            name="dxx_id",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=9
        ),
        InputText(
            label="学校",
            description="对应青春湖北填写信息页 高校",
            name="university",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=24
        ),
        InputText(
            label="学院",
            description="对应青春湖北填写信息页 院系",
            name="college",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=32
        ),
        InputText(
            label="团支部",
            description="对应青春湖北填写信息页 选择组织",
            name="organization",
            inline=False,
            required=False,
            value="",
            clearable=True,
            maxLength=32
        )

    ]
)

hubei_page = Page(title='添加大学习', body=[logo, Divider(), hubei_table, footer])
jiangxi_table = Form(
    title="江西共青团",
    mode=DisplayModeEnum.horizontal,
    api="post:/TeenStudy/api/jiangxi/add",
    redirect="/TeenStudy/login",
    body=[
        InputText(
            label="用户ID",
            description="用户ID，为用户QQ号，无需填写",
            name="user_id",
            value="${user_id}",
            disabled=True
        ),
        InputText(
            label="通知群ID",
            description="通知群号，无需填写",
            name="group_id",
            value="${group_id}",
            disabled=True
        ),
        InputText(
            label="地区",
            description="所处省份",
            name="area",
            value="江西",
            disabled=True
        ),
        InputText(
            label="登录密码",
            type='input-password',
            description="可不填，默认为用户ID",
            name="password",
            inline=False,
            required=False,
            value="",
            clearable=True,
            maxLength=16
        ),
        InputText(
            label="url",
            description="点进江西共青团选择青年大学习H5，进去后点右上角三个点，复制链接填入即可 链接格式：http://www.jxqingtuan.cn/html/?accessToken=xxxxxx&openid=xxxxxxxxxxxx&requestType=http#/",
            name="url",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=512
        )

    ]
)

jiangxi_page = Page(title='添加大学习', body=[logo, Divider(), jiangxi_table, footer])

anhui_table = Form(
    title="安徽共青团",
    mode=DisplayModeEnum.horizontal,
    api="post:/TeenStudy/api/anhui/add",
    redirect="/TeenStudy/login",
    body=[
        InputText(
            label="用户ID",
            description="用户ID，为用户QQ号，无需填写",
            name="user_id",
            value="${user_id}",
            disabled=True
        ),
        InputText(
            label="通知群ID",
            description="通知群号，无需填写",
            name="group_id",
            value="${group_id}",
            disabled=True
        ),
        InputText(
            label="地区",
            description="所处省份",
            name="area",
            value="安徽",
            disabled=True
        ),
        InputText(
            label="登录密码",
            type='input-password',
            description="可不填，默认为用户ID",
            name="password",
            inline=False,
            required=False,
            value="",
            clearable=True,
            maxLength=16
        ),
        InputText(
            label="url",
            description="个人信息修改页，点右上角分享，复制链接填入即可 链接格式：http://dxx.ahyouth.org.cn/modify/?tk=您的token值",
            name="url",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=128
        )
    ]
)

anhui_page = Page(title='添加大学习', body=[logo, Divider(), anhui_table, footer])

sichuan_table = Form(
    title="天府新青年",
    mode=DisplayModeEnum.horizontal,
    api="post:/TeenStudy/api/sichuan/add",
    redirect="/TeenStudy/login",
    body=[
        Alert(level=LevelEnum.info,
              className='white-space-pre-wrap',
              body=(
                  "该地区需要自行抓包填入\ntoken值在https://dxx.scyol.com/api/wechat/login 响应里\n其余信息在 https://dxx.scyol.com/api/student/showStudyStageOrg?id=xxxxxx&stageId=xx 响应里")),
        InputText(
            label="用户ID",
            description="用户ID，为用户QQ号，无需填写",
            name="user_id",
            value="${user_id}",
            disabled=True
        ),
        InputText(
            label="通知群ID",
            description="通知群号，无需填写",
            name="group_id",
            value="${group_id}",
            disabled=True
        ),
        InputText(
            label="地区",
            description="所处省份",
            name="area",
            value="四川",
            disabled=True
        ),
        InputText(
            label="登录密码",
            type='input-password',
            description="可不填，默认为用户ID",
            name="password",
            inline=False,
            required=False,
            value="",
            clearable=True,
            maxLength=16
        ),
        InputText(
            label="姓名",
            description="对应抓包内容 name",
            name="name",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=8
        ),
        InputText(
            label="token",
            description="自行抓包获取，在：https://dxx.scyol.com/api/wechat/login 链接的响应内容里",
            name="token",
            inline=False,
            required=True,
            value="",
            clearable=True,
        ),
        InputText(
            label="手机号",
            description="自行抓包获取，对应tel",
            name="mobile",
            inline=False,
            required=True,
            value="",
            clearable=True,
        ),
        InputText(
            label="整体组织ID",
            description="自行抓包获取，对应org",
            name="org",
            inline=False,
            required=True,
            value="",
            clearable=True,
        ),
        InputText(
            label="组织ID",
            description="自行抓包获取，对应lastOrg",
            name="lastOrg",
            inline=False,
            required=True,
            value="",
            clearable=True,
        ),
        InputText(
            label="团支部名称",
            description="自行抓包获取，对应 orgName",
            name="orgName",
            inline=False,
            required=True,
            value="",
            clearable=True,
        ), InputText(
            label="组织全称",
            description="自行抓包获取，对应allOrgName",
            name="allOrgName",
            inline=False,
            required=True,
            value="",
            clearable=True,
        )

    ]
)

sichuan_page = Page(title='添加大学习', body=[logo, Divider(), sichuan_table, footer])

shandong_table = Form(
    title="青春山东",
    mode=DisplayModeEnum.horizontal,
    api="post:/TeenStudy/api/shandong/add",
    redirect="/TeenStudy/login",
    body=[
        InputText(
            label="用户ID",
            description="用户ID，为用户QQ号，无需填写",
            name="user_id",
            value="${user_id}",
            disabled=True
        ),
        InputText(
            label="通知群ID",
            description="通知群号，无需填写",
            name="group_id",
            value="${group_id}",
            disabled=True
        ),
        InputText(
            label="地区",
            description="所处省份",
            name="area",
            value="山东",
            disabled=True
        ),
        InputText(
            label="登录密码",
            type='input-password',
            description="可不填，默认为用户ID",
            name="password",
            inline=False,
            required=False,
            value="",
            clearable=True,
            maxLength=16
        ),
        InputText(
            label="姓名",
            description="对应青春山东个人信息页 您的姓名",
            name="name",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=8
        ),
        InputText(
            label="cookie",
            description="自行抓包获取，结构为：JSESSIONID=1873FXXXXXXXX5DFCBF1CC13703",
            name="cookie",
            inline=False,
            required=True,
            value="",
            clearable=True,
        ),
        InputText(
            label="openid",
            description="自行抓包获取，结构为: ohz9xxxxxxxxxxxxlF0Io0uCnM",
            name="openid",
            inline=False,
            required=True,
            value="",
            clearable=True,
        )

    ]
)

shandong_page = Page(title='添加大学习', body=[logo, Divider(), shandong_table, footer])

chongqing_table = Form(
    title="重庆共青团",
    mode=DisplayModeEnum.horizontal,
    api="post:/TeenStudy/api/chongqing/add",
    redirect="/TeenStudy/login",
    body=[
        InputText(
            label="用户ID",
            description="用户ID，为用户QQ号，无需填写",
            name="user_id",
            value="${user_id}",
            disabled=True
        ),
        InputText(
            label="通知群ID",
            description="通知群号，无需填写",
            name="group_id",
            value="${group_id}",
            disabled=True
        ),
        InputText(
            label="地区",
            description="所处省份",
            name="area",
            value="重庆",
            disabled=True
        ),
        InputText(
            label="登录密码",
            type='input-password',
            description="可不填，默认为用户ID",
            name="password",
            inline=False,
            required=False,
            value="",
            clearable=True,
            maxLength=16
        ),
        InputText(
            label="姓名",
            description="对应重庆共青团个人信息页 您的姓名",
            name="name",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=8
        ),
        InputText(
            label="openid",
            description="自行抓包获取，结构为: ohz9xxxxxxxxxxxxlF0Io0uCnM",
            name="openid",
            inline=False,
            required=True,
            value="",
            clearable=True,
        )

    ]
)

chongqing_page = Page(title='添加大学习', body=[logo, Divider(), chongqing_table, footer])

jilin_table = Form(
    title="吉青飞扬",
    mode=DisplayModeEnum.horizontal,
    api="post:/TeenStudy/api/jilin/add",
    redirect="/TeenStudy/login",
    body=[
        InputText(
            label="用户ID",
            description="用户ID，为用户QQ号，无需填写",
            name="user_id",
            value="${user_id}",
            disabled=True
        ),
        InputText(
            label="通知群ID",
            description="通知群号，无需填写",
            name="group_id",
            value="${group_id}",
            disabled=True
        ),
        InputText(
            label="地区",
            description="所处省份",
            name="area",
            value="吉林",
            disabled=True
        ),
        InputText(
            label="登录密码",
            type='input-password',
            description="可不填，默认为用户ID",
            name="password",
            inline=False,
            required=False,
            value="",
            clearable=True,
            maxLength=16
        ),
        InputText(
            label="姓名",
            description="您的姓名",
            name="name",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=8
        ),
        InputText(
            label="openid",
            description="自行抓包获取，结构为: ohz9xxxxxxxxxxxxlF0Io0uCnM",
            name="openid",
            inline=False,
            required=True,
            value="",
            clearable=True,
        ),
        InputText(
            label="学校",
            description="你就读的高校",
            name="university",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=24
        ),
        InputText(
            label="学院",
            description="学院名称",
            name="college",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=32
        ),
        InputText(
            label="团支部",
            description="团支部|班级，没有可不填",
            name="organization",
            inline=False,
            required=False,
            value="",
            clearable=True,
            maxLength=32
        )

    ]
)

jilin_page = Page(title='添加大学习', body=[logo, Divider(), jilin_table, footer])

guangdong_table = Form(
    title="广东共青团",
    mode=DisplayModeEnum.horizontal,
    api="post:/TeenStudy/api/guangdong/add",
    redirect="/TeenStudy/login",
    body=[
        Alert(level=LevelEnum.info,
              className='white-space-pre-wrap',
              body=(
                  "链接获取方式:\n12355青春之声公众号\n智慧团建-认证资料-生成电子团员证，点击最下方生成按钮。\n在团员证页面复制链接 应为：https://tuan.12355.net/wechat/view/information/member_certification_generated.html?memberId=xxxxxx&showMemberAdditionNames=&showMemberRewardIds=&isShowAllFee=true \n其中xxxxxx即为mid")),
        InputText(
            label="用户ID",
            description="用户ID，为用户QQ号，无需填写",
            name="user_id",
            value="${user_id}",
            disabled=True
        ),
        InputText(
            label="通知群ID",
            description="通知群号，无需填写",
            name="group_id",
            value="${group_id}",
            disabled=True
        ),
        InputText(
            label="地区",
            description="所处省份",
            name="area",
            value="广东",
            disabled=True
        ),
        InputText(
            label="登录密码",
            type='input-password',
            description="可不填，默认为用户ID",
            name="password",
            inline=False,
            required=False,
            value="",
            clearable=True,
            maxLength=16
        ),
        InputText(
            label="姓名",
            description="您的姓名",
            name="name",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=8
        ),
        InputText(
            label="url",
            description="链接格式：https://tuan.12355.net/wechat/view/information/member_certification_generated.html?memberId=xxxxxx&showMemberAdditionNames=&showMemberRewardIds=&isShowAllFee=true",
            name="url",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=512
        ),
        InputText(
            label="学校",
            description="你就读的高校",
            name="university",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=24
        ),
        InputText(
            label="学院",
            description="学院名称",
            name="college",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=32
        ),
        InputText(
            label="团支部",
            description="团支部|班级，没有可不填",
            name="organization",
            inline=False,
            required=False,
            value="",
            clearable=True,
            maxLength=32
        )]
)

guangdong_page = Page(title='添加大学习', body=[logo, Divider(), guangdong_table, footer])

beijing_table = Form(
    title="北京共青团",
    mode=DisplayModeEnum.horizontal,
    api="post:/TeenStudy/api/beijing/add",
    redirect="/TeenStudy/login",
    body=[
        InputText(
            label="用户ID",
            description="用户ID，为用户QQ号，无需填写",
            name="user_id",
            value="${user_id}",
            disabled=True
        ),
        InputText(
            label="通知群ID",
            description="通知群号，无需填写",
            name="group_id",
            value="${group_id}",
            disabled=True
        ),
        InputText(
            label="地区",
            description="所处省份",
            name="area",
            value="北京",
            disabled=True
        ),
        InputText(
            label="登录密码",
            type='input-password',
            description="可不填，默认为用户ID",
            name="password",
            inline=False,
            required=False,
            value="",
            clearable=True,
            maxLength=16
        ),
        InputText(
            label="姓名",
            description="您的姓名",
            name="name",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=8
        ), InputText(
            label="大学习ID",
            description="名字后面括号内的数字",
            name="dxx_id",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=8
        ),
        InputText(
            label="学校",
            description="你就读的高校",
            name="university",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=24
        ),
        InputText(
            label="学院",
            description="学院名称",
            name="college",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=32
        ),
        InputText(
            label="团支部",
            description="团支部|班级，没有可不填",
            name="organization",
            inline=False,
            required=False,
            value="",
            clearable=True,
            maxLength=32
        ),
        InputText(
            label="团支部ID",
            description="支部后面括号内的数字",
            name="organization_id",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=32
        ),
        InputText(
            label="账号",
            description="登录北京共青团的账号",
            name="cookie",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=32
        ), InputText(
            label="密码",
            description="登陆北京共青团的密码",
            name="token",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=32
        )
    ]
)

beijing_page = Page(title='添加大学习', body=[logo, Divider(), beijing_table, footer])

tianjin_table = Form(
    title="津彩青春",
    mode=DisplayModeEnum.horizontal,
    api="post:/TeenStudy/api/tianjin/add",
    redirect="/TeenStudy/login",
    body=[
        InputText(
            label="用户ID",
            description="用户ID，为用户QQ号，无需填写",
            name="user_id",
            value="${user_id}",
            disabled=True
        ),
        InputText(
            label="通知群ID",
            description="通知群号，无需填写",
            name="group_id",
            value="${group_id}",
            disabled=True
        ),
        InputText(
            label="地区",
            description="所处省份",
            name="area",
            value="天津",
            disabled=True
        ),
        InputText(
            label="登录密码",
            type='input-password',
            description="可不填，默认为用户ID",
            name="password",
            inline=False,
            required=False,
            value="",
            clearable=True,
            maxLength=16
        ),
        InputText(
            label="姓名",
            description="您的姓名",
            name="name",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=8
        ),
        InputText(
            label="学校",
            description="你就读的高校",
            name="university",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=24
        ),
        InputText(
            label="学院",
            description="学院名称",
            name="college",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=32
        ),
        InputText(
            label="团支部",
            description="团支部|班级，没有可不填",
            name="organization",
            inline=False,
            required=False,
            value="",
            clearable=True,
            maxLength=32
        ),
        InputText(
            label="cookie",
            description="自行抓包获取，结构为：JSESSIONID=1873FXXXXXXXX5DFCBF1CC13703",
            name="cookie",
            inline=False,
            required=True,
            value="",
            clearable=True,
        ),
    ]
)

tianjin_page = Page(title='添加大学习', body=[logo, Divider(), tianjin_table, footer])

shanxi_table = Form(
    title="三秦青年",
    mode=DisplayModeEnum.horizontal,
    api="post:/TeenStudy/api/shanxi/add",
    redirect="/TeenStudy/login",
    body=[
        InputText(
            label="用户ID",
            description="用户ID，为用户QQ号，无需填写",
            name="user_id",
            value="${user_id}",
            disabled=True
        ),
        InputText(
            label="通知群ID",
            description="通知群号，无需填写",
            name="group_id",
            value="${group_id}",
            disabled=True
        ),
        InputText(
            label="地区",
            description="所处省份",
            name="area",
            value="陕西",
            disabled=True
        ),
        InputText(
            label="登录密码",
            type='input-password',
            description="可不填，默认为用户ID",
            name="password",
            inline=False,
            required=False,
            value="",
            clearable=True,
            maxLength=16
        ),
        InputText(
            label="姓名",
            description="您的姓名",
            name="name",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=8
        ),
        InputText(
            label="学校",
            description="你就读的高校",
            name="university",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=24
        ),
        InputText(
            label="学院",
            description="学院名称",
            name="college",
            inline=False,
            required=True,
            value="",
            clearable=True,
            maxLength=32
        ),
        InputText(
            label="团支部",
            description="团支部|班级，没有可不填",
            name="organization",
            inline=False,
            required=False,
            value="",
            clearable=True,
            maxLength=32
        ),
        InputText(
            label="token",
            description="自行抓包获取",
            name="token",
            inline=False,
            required=True,
            value="",
            clearable=True,
        ),
    ]
)

shanxi_page = Page(title='添加大学习', body=[logo, Divider(), shanxi_table, footer])



from nonebot import get_driver
from nonebot.plugin import PluginMetadata

from . import models, utils, web

__plugin_meta__ = PluginMetadata(
    name='青年大学习提交',
    description='一个可以自动提交多地区青年大学习的插件',
    usage='添加大学习',
    homepage="https://github.com/YouthLearning/TeenStudy",
    type="application",
    supported_adapters={"~onebot.v11"},
    extra={
        'author': 'TeenStudyFlow',
        'version': '0.2.4',
        'priority': 50,
    }

)

DRIVER = get_driver()


@DRIVER.on_startup
async def startup():
    await utils.path.connect()
    await utils.utils.admin_init()
    await utils.utils.plugin_init()
    await utils.utils.resource_init()
    await utils.update.update_answer()
    await utils.update.update_shanxi()
    await utils.update.update_shandong()
    await utils.update.update_jiangxi()


DRIVER.on_shutdown(utils.path.disconnect)



import json
import re
import secrets
import time
import urllib.parse
from typing import Optional

from anti_useragent import UserAgent
from bs4 import BeautifulSoup
from ddddocr import DdddOcr
from httpx import AsyncClient
from nonebot import logger

from .utils import encrypt
from ..models.accuont import User, Commit
from ..models.dxx import Answer, JiangXiDxx, ShanDongDxx, ShanXiDxx

headers = {
    'Accept': 'application/json, text/plain, */*',
    'Accept-Encoding': 'gzip, deflate',
    'Accept-Language': 'zh-CN,zh;q=0.9,en-US;q=0.8,en;q=0.7',
    'Connection': 'keep-alive',
    'Content-Type': 'application/json;charset=UTF-8',
    'User-Agent': UserAgent(platform="iphone", min_version=1, max_version=5).wechat,
    'X-Requested-With': 'XMLHttpRequest'
}


async def commit(user_id: int, catalogue: str, status: bool = False) -> None:
    """
    记录提交状态
    :param catalogue: 提交期数
    :param user_id: 用户ID
    :param status:提交状态，默认为False
    :return:
    """
    result = await User.filter(user_id=user_id).values()
    await Commit.create(
        time=time.time(),
        user_id=user_id,
        area=result[0]["area"],
        status=status,
        name=result[0]["name"],
        university=result[0]["university"],
        college=result[0]["college"],
        organization=result[0]["organization"],
        catalogue=catalogue
    )


async def hubei(user_id: int, catalogue: Optional[str] = None) -> dict:
    """
    青春湖北
    :param catalogue: 期数
    :param user_id:用户ID
    :return:
    """
    result = await User.filter(user_id=user_id).values()
    if not result:
        return {
            "status": 500,
            "msg": "用户数据不存在！"
        }
    else:
        if not catalogue:
            resp_url = 'https://h5.cyol.com/special/weixin/sign.json'
            async with AsyncClient(headers=headers) as client:
                response = await client.get(url=resp_url, timeout=10)
            response.encoding = response.charset_encoding
            result = response.json()
            code_result = list(result)[-1]
            answer = await Answer.filter(code=code_result).values()
            catalogue = answer[-1]["catalogue"]
        name = result[0]["name"]
        openid = result[0]["openid"]
        university = result[0]["university"]
        college = result[0]["college"]
        organization = result[0]["organization"]
        headers.update({
            "Host": "cp.fjg360.cn",
            "X-Requested-With": "XMLHttpRequest",
            "Sec-Fetch-Site": "same-origin",
            "Sec-Fetch-Mode": "cors",
            "Sec-Fetch-Dest": "empty",
            "Accept-Encoding": "gzip, deflate",
            "Accept-Language": "zh-CN,zh;q=0.9,en-US;q=0.8,en;q=0.7",
        })
        url = "https://cp.fjg360.cn/index.php?m=vote&c=index&a=save_door&sessionId=&imgTextId=&ip="
        url += "&username=" + name
        url += "&phone=" + "未知"
        url += "&city=" + university
        url += "&danwei2=" + organization
        url += "&danwei=" + college
        url += "&openid=" + openid
        url += "&num=10"
        url += "&lesson_name=" + catalogue
        try:
            async with AsyncClient(headers=headers) as client:
                response = await client.get(url)
            response_json = json.loads(response.text)
            if response_json.get('code') == 1:
                await User.filter(user_id=user_id).update(
                    commit_time=time.time(),
                    catalogue=catalogue
                )
                await commit(user_id=user_id, catalogue=catalogue, status=True)
                return {
                    "status": 0,
                    "catalogue": catalogue,
                    "msg": "提交成功！"
                }
            else:
                await commit(user_id=user_id, catalogue=catalogue, status=False)
                return {
                    "status": 500,
                    "msg": "提交失败！"
                }
        except Exception as e:
            logger.error(e)
            await commit(user_id=user_id, catalogue=catalogue, status=False)
            return {
                "status": 500,
                "msg": "提交失败！"
            }


async def jiangxi(user_id: int, catalogue: Optional[str] = None) -> dict:
    """
    江西共青团
    :param catalogue:
    :param user_id:用户ID
    :return:
    """
    result = await User.filter(user_id=user_id).values()
    if catalogue:
        filterArg = {
            "title": catalogue
        }
    else:
        filterArg = {}
    if not result:
        return {
            "status": 500,
            "msg": "用户数据不存在！"
        }
    else:
        name = result[0]["name"]
        nid = result[0]["dxx_id"]
        openid = result[0]["openid"]
        token = result[0]["token"]
        if result[0]["mobile"]:
            suborg = result[0]["mobile"]
        else:
            suborg = ''
        code = await JiangXiDxx.filter(**filterArg).order_by("code").values()
        if not code:
            return {
                "status": 404,
                "msg": f"江西共青团没有找到青年大学习{catalogue}"
            }
        try:
            headers.update({
                'Cookie': 'JSESSIONID=' + secrets.token_urlsafe(40),
                'Host': 'www.jxqingtuan.cn',
                'Origin': 'http://www.jxqingtuan.cn',
                'Referer': 'http://www.jxqingtuan.cn/html/h5_index.html?&accessToken=' + openid,
                'openid': openid
            })
            async with AsyncClient(headers=headers) as client:
                course = code[-1]["code"]
                resp_url = 'http://www.jxqingtuan.cn/pub/pub/vol/volClass/join?accessToken='
                data = {"course": course, "nid": nid, "cardNo": name, "subOrg": suborg}
                res = await client.post(url=resp_url, json=data)
                res.encoding = res.charset_encoding
                resp = json.loads(res.text)
                if resp.get("status") == 200:
                    await User.filter(user_id=user_id).update(
                        commit_time=time.time(),
                        catalogue=catalogue
                    )
                    await commit(user_id=user_id, catalogue=catalogue, status=True)
                    data = {
                        "check": 1,
                        "type": 3,
                        "title": "青年大学习",
                        "url": code[-1]['url'],
                        "openid": openid,
                        "userId": token
                    }
                    response = await client.post('http://www.jxqingtuan.cn/pub/pub/vol/member/addScoreInfo',
                                                 params=data)
                    if response.json()["code"] == "200" or response.json()["code"] == "-1":
                        return {
                            "status": 0,
                            "catalogue": catalogue,
                            "msg": "提交成功！"
                        }
                    return {
                        "status": 0,
                        "catalogue": catalogue,
                        "msg": "提交成功！"
                    }
                else:
                    await commit(user_id=user_id, catalogue=catalogue, status=False)
                    return {
                        "status": 500,
                        "msg": "提交失败,信息错误！"
                    }
        except Exception as e:
            logger.error(e)
            await commit(user_id=user_id, catalogue=catalogue, status=False)
            return {
                "status": 500,
                "msg": f"提交失败,{e}"
            }


async def zhejiang(user_id: int) -> dict:
    """
    青春浙江
    :param user_id:
    :return:
    """
    result = await User.filter(user_id=user_id).values()
    if not result:
        return {
            "status": 500,
            "msg": "用户数据不存在！"
        }
    else:
        nickname = result[0]["token"]
        name = result[0]["name"]
        nid = result[0]["dxx_id"]
        openid = result[0]["openid"]
        cookie = result[0]["cookie"]
        if result[0]["mobile"]:
            suborg = result[0]["mobile"]
        else:
            suborg = None
        answer = await Answer.all().order_by("time").values()
        try:
            headers = {
                "Host": "qczj.h5yunban.com",
                "Connection": "keep-alive",
                "Accept": "application/json, text/javascript, */*; q=0.01",
                "X-Requested-With": "XMLHttpRequest",
                "User-Agent": "Mozilla/5.0 (Linux; Android 12; M2007J3SC Build/SKQ1.220303.001; wv) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/86.0.4240.99 XWEB/3262 MMWEBSDK/20220204 Mobile Safari/537.36 MMWEBID/6170 MicroMessenger/8.0.20.2100(0x28001438) Process/toolsmp WeChat/arm32 Weixin NetType/WIFI Language/zh_CN ABI/arm64",
                "Content-Type": "application/json;charset=UTF-8",
                "Sec-Fetch-Site": "same-origin",
                "Sec-Fetch-Mode": "cors",
                "Sec-Fetch-Dest": "empty",
                "Accept-Encoding": "gzip, deflate",
                "Accept-Language": "zh-CN,zh;q=0.9,en-US;q=0.8,en;q=0.7",
            }
            url = f"https://qczj.h5yunban.com/qczj-youth-learning/cgi-bin/login/we-chat/callback?callback=https%3A%2F%2Fqczj.h5yunban.com%2Fqczj-youth-learning%2Findex.php&scope=snsapi_userinfo&appid=wx56b888a1409a2920&openid={openid}&nickname={nickname}&headimg={cookie}&time={int(time.time())}&source=common&sign=&t={int(time.time())}"
            async with AsyncClient(headers=headers) as client:
                response = await client.get(url)
                response.encoding = response.charset_encoding
                accessToken = re.findall(r"\(\'accessToken\'\,\s+\'(.+?)\'\)", response.text)[0]
                study_url = f"https://qczj.h5yunban.com/qczj-youth-learning/cgi-bin/common-api/course/current?accessToken={accessToken}"
                response = await client.get(url=study_url)
                response.encoding = response.charset_encoding
                if response.json()['status'] == 200:
                    title = response.json()["result"]['title']
                    course = response.json()['result']['id']
                    commit_url = f"https://qczj.h5yunban.com/qczj-youth-learning/cgi-bin/user-api/course/join?accessToken={accessToken}"
                    params = {
                        "course": course,
                        "subOrg": suborg,
                        "nid": nid,
                        "cardNo": name
                    }
                    response = await client.post(url=commit_url, json=params)
                    response.encoding = response.charset_encoding
                    if response.json()['status'] == 200:
                        await User.filter(user_id=user_id).update(
                            commit_time=time.time(),
                            catalogue=title
                        )
                        await commit(user_id=user_id, catalogue=title, status=True)
                        return {
                            "status": 0,
                            "catalogue": title,
                            "msg": "提交成功！"
                        }
                    else:
                        await commit(user_id=user_id, catalogue=title, status=False)
                        return {
                            "status": 500,
                            "msg": "提交失败，信息错误！"
                        }
                else:
                    await commit(user_id=user_id, catalogue=answer[-1]["catalogue"], status=False)
                    return {
                        "status": 500,
                        "msg": "提交失败，青春浙江访问失败！"
                    }
        except Exception as e:
            logger.error(e)
            await commit(user_id=user_id, catalogue=answer[-1]["catalogue"], status=False)
            return {
                "status": 500,
                "msg": f"提交失败,{e}"
            }


async def shanghai(user_id: int) -> dict:
    """
    青春上海
    :param user_id:
    :return:
    """
    result = await User.filter(user_id=user_id).values()
    if not result:
        return {
            "status": 500,
            "msg": "用户数据不存在！"
        }
    else:
        nickname = result[0]["token"]
        name = result[0]["name"]
        nid = result[0]["dxx_id"]
        openid = result[0]["openid"]
        cookie = result[0]["cookie"]
        if result[0]["mobile"]:
            suborg = result[0]["mobile"]
        else:
            suborg = None
        answer = await Answer.all().order_by("time").values()
        try:
            headers = {
                "Host": "qcsh.h5yunban.com",
                "Connection": "keep-alive",
                "Accept": "application/json, text/javascript, */*; q=0.01",
                "X-Requested-With": "XMLHttpRequest",
                "User-Agent": "Mozilla/5.0 (Linux; Android 12; M2007J3SC Build/SKQ1.220303.001; wv) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/86.0.4240.99 XWEB/3262 MMWEBSDK/20220204 Mobile Safari/537.36 MMWEBID/6170 MicroMessenger/8.0.20.2100(0x28001438) Process/toolsmp WeChat/arm32 Weixin NetType/WIFI Language/zh_CN ABI/arm64",
                "Content-Type": "application/json;charset=UTF-8",
                "Sec-Fetch-Site": "same-origin",
                "Sec-Fetch-Mode": "cors",
                "Sec-Fetch-Dest": "empty",
                "Referer": "https://qcsh.h5yunban.com/youth-learning/signUp.php?rv=2020",
                "Accept-Encoding": "gzip, deflate",
                "Accept-Language": "zh-CN,zh;q=0.9,en-US;q=0.8,en;q=0.7",
            }
            url = f"https://qcsh.h5yunban.com/youth-learning/cgi-bin/login/we-chat/callback?appid=wxa693f4127cc93fad&openid={openid}&nickname={nickname}&headimg={cookie}&callback=https://qcsh.h5yunban.com/youth-learning/&scope=snsapi_userinfo"
            async with AsyncClient(headers=headers) as client:
                response = await client.get(url)
                response.encoding = response.charset_encoding
                accessToken = re.findall(r"\(\'accessToken\'\,\s+\'(.+?)\'\)", response.text)[0]
                study_url = f"https://qcsh.h5yunban.com/youth-learning/cgi-bin/common-api/course/current?accessToken={accessToken}"
                response = await client.get(url=study_url)
                response.encoding = response.charset_encoding
                if response.json()['status'] == 200:
                    title = response.json()["result"][0]['title']
                    course = response.json()['result'][0]['id']
                    commit_url = f"https://qcsh.h5yunban.com/youth-learning/cgi-bin/user-api/course/join?accessToken={accessToken}"
                    params = {
                        "course": course,
                        "subOrg": suborg,
                        "nid": nid,
                        "cardNo": name
                    }
                    response = await client.post(url=commit_url, json=params)
                    response.encoding = response.charset_encoding
                    if response.json()['status'] == 200:
                        await User.filter(user_id=user_id).update(
                            commit_time=time.time(),
                            catalogue=title
                        )
                        await commit(user_id=user_id, catalogue=title, status=True)
                        return {
                            "status": 0,
                            "catalogue": title,
                            "msg": "提交成功！"
                        }
                    else:
                        await commit(user_id=user_id, catalogue=title, status=False)
                        return {
                            "status": response.json()["status"],
                            "msg": response.json()["message"]
                        }
                else:
                    await commit(user_id=user_id, catalogue=answer[-1]["catalogue"], status=False)
                    return {
                        "status": 500,
                        "msg": "提交失败，青春上海访问失败！"
                    }
        except Exception as e:
            logger.error(e)
            await commit(user_id=user_id, catalogue=answer[-1]["catalogue"], status=False)
            return {
                "status": 500,
                "msg": "提交失败！"
            }


async def anhui(user_id: int) -> dict:
    """
    安徽共青团
    :param user_id:用户ID
    :return:
    """
    result = await User.filter(user_id=user_id).values()
    if not result:
        return {
            "status": 500,
            "msg": "用户数据不存在！"
        }
    else:
        username = result[0]['name']
        gender = result[0]['gender']
        mobile = result[0]['mobile']
        level1 = result[0]['university_type']
        level2 = result[0]['university']
        level3 = result[0]['college']
        level4 = result[0]['organization']
        level5 = result[0]['organization_id']
        token = result[0]["token"]
        answer = await Answer.all().order_by("time").values()
        try:
            headers = {
                "Host": "dxx.ahyouth.org.cn",
                "Accept": "application/json, text/plain, */*",
                "Accept-Language": "zh-CN,zh;q=0.9,en-US;q=0.8,en;q=0.7",
                "Referer": "http://dxx.ahyouth.org.cn/",
                "Accept-Encoding": "gzip, deflate",
                "Connection": "keep-alive",
                'Content-Type': 'application/x-www-form-urlencoded',
                "X-Requested-With": 'com.tencent.mm',
                "Origin": 'http://dxx.ahyouth.org.cn',
                "token": token
            }
            data = {
                'username': username,
                'gender': gender,
                'mobile': mobile,
                'level1': level1,
                'level2': level2,
                'level3': level3,
                'level4': level4,
                'level5': level5
            }
            get_infor_url = 'http://dxx.ahyouth.org.cn/api/saveUserInfo'
            async with AsyncClient(headers=headers, timeout=30, max_redirects=5) as client:
                infor_response = await client.post(url=get_infor_url, params=data)
                infor_response.encoding = infor_response.charset_encoding
                infor_response_json = infor_response.json()
                if infor_response_json['code'] == 200:
                    username = infor_response_json['content']['username']
                    token = infor_response_json['content']['token']
                    gender = infor_response_json['content']['gender']
                    mobile = infor_response_json['content']['mobile']
                    level1 = infor_response_json['content']['level1']
                    level2 = infor_response_json['content']['level2']
                    level3 = infor_response_json['content']['level3']
                    level4 = infor_response_json['content']['level4']
                    level5 = infor_response_json['content']['level5']
                    data = {
                        'username': username,
                        'gender': gender,
                        'mobile': mobile,
                        'level1': level1,
                        'level2': level2,
                        'level3': level3,
                        'level4': level4,
                        'level5': level5
                    }
                    commit_url = 'http://dxx.ahyouth.org.cn/api/newLearn'
                    commit_response = await client.post(url=commit_url, params=data)
                    commit_response.encoding = commit_response.charset_encoding
                    commit_response_json = commit_response.json()
                    if commit_response_json['code'] == 200:
                        await User.filter(user_id=user_id).update(
                            token=token,
                            commit_time=time.time(),
                            catalogue=answer[-1]["catalogue"]
                        )
                        await commit(user_id=user_id, catalogue=answer[-1]["catalogue"], status=True)
                        return {
                            "status": 0,
                            "catalogue": answer[-1]["catalogue"],
                            "msg": "提交成功！"
                        }
                    else:
                        await commit(user_id=user_id, catalogue=answer[-1]["catalogue"], status=False)
                        return {
                            "status": 500,
                            "msg": "提交失败，token失效！"
                        }
                else:
                    await commit(user_id=user_id, catalogue=answer[-1]["catalogue"], status=False)
                    return {
                        "status": 500,
                        "msg": "提交失败,token获取失败！"
                    }
        except Exception as e:
            logger.error(e)
            await commit(user_id=user_id, catalogue=answer[-1]["catalogue"], status=False)
            return {
                "status": 500,
                "msg": f"提交失败,{e}"
            }


async def sichuan(user_id: int) -> dict:
    """
    天府新青年
    :param user_id:
    :return:
    """
    result = await User.filter(user_id=user_id).values()
    if not result:
        return {
            "status": 500,
            "msg": "用户数据不存在！"
        }
    else:
        token = result[0]["token"]
        university_type = result[0]["university_type"]
        university_id = result[0]["university_id"]
        university = result[0]["university"]
        name = result[0]["name"]
        mobile = result[0]["mobile"]
        college_id = result[0]["college_id"]
        college = result[0]["college"]
        organization_id = result[0]["organization_id"]
        organization = result[0]["organization"]
        dxx_id = result[0]["dxx_id"]
        data_json = {
            "name": name,
            "tel": mobile,
            "org": f"#{dxx_id}#{university_id}#{college_id}#{organization_id}#",
            "lastOrg": organization_id,
            "orgName": organization,
            "allOrgName": f"#{university_type}#{university}#{college}#{organization}#"
        }
        headers.update({
            "Referer": 'http://scyol.com/v_prod6.02/',
            "Host": "dxx.scyol.com",
            "Connection": "keep-alive",
            "Content_Length": '9',
            "Content_Type": "application/json",
            "Accept": "*/*",
            "User-Agent": "Mozilla/5.0 (Linux; Android 11; M2007J3SC Build/SKQ1.220213.001; wv) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/86.0.4240.99 XWEB/3224 MMWEBSDK/20210902 Mobile Safari/537.36 MMWEBID/6170 MicroMessenger/8.0.15.2020(0x28000F30) Process/toolsmp WeChat/arm32 Weixin NetType/WIFI Language/zh_CN ABI/arm64",
            "Origin": "http://scyol.com",
            "X-Requested-With": "com.tencent.mm",
            "Sec-Fetch-Site": "same-origin",
            "Sec-Fetch-Mode": "cors",
            "Sec-Fetch-Dest": "empty",
            "token": token,
            "Accept-Encoding": "gzip, deflate",
            "Accept-Language": "zh-CN,zh;q=0.9,en-US;q=0.8,en;q=0.7",
        })
        answer = await Answer.all().order_by("time").values()
        title = answer[-1]["catalogue"]
        url = 'https://dxx.scyol.com/api/student/commit'
        try:
            async with AsyncClient(headers=headers) as client:
                response = await client.post(url=url, json=data_json)
                if response.status_code == 200:
                    response.encoding = response.charset_encoding
                    if response.json()["code"] == 2:
                        await User.filter(user_id=user_id).update(
                            commit_time=time.time(),
                            catalogue=title
                        )
                        await commit(user_id=user_id, catalogue=title, status=True)
                        return {
                            "status": 0,
                            "catalogue": title,
                            "msg": "你已经提交了，请勿重复提交哦"
                        }
                    elif response.json()["code"] == 200:
                        await User.filter(user_id=user_id).update(
                            commit_time=time.time(),
                            catalogue=title
                        )
                        await commit(user_id=user_id, catalogue=title, status=True)
                        return {
                            "status": 0,
                            "catalogue": title,
                            "msg": "提交成功！"
                        }
                    else:
                        await commit(user_id=user_id, catalogue=answer[-1]["catalogue"], status=False)
                        return {
                            "status": 500,
                            "msg": "提交失败！"
                        }
                else:
                    return {
                        "status": 500,
                        "msg": "提交失败,cookie失效！"
                    }
        except Exception as e:
            return {
                "status": 500,
                "msg": f"提交失败,{e}"
            }


async def shandong(user_id: int, catalogue: Optional[str] = None) -> dict:
    """
    青春山东
    :param catalogue:
    :param user_id: 用户ID
    :return:
    """
    result = await User.filter(user_id=user_id).values()
    if not result:
        return {
            "status": 500,
            "msg": "用户数据不存在！"
        }
    else:
        if catalogue:
            filterArg = {
                "title": catalogue
            }
            answer = await ShanDongDxx.filter(**filterArg).order_by("time").values()
            version = answer[-1]["version"]
            title = catalogue
        else:
            new_version_url = f'http://qndxx.youth54.cn/SmartLA/dxxjfgl.w?method=getNewestVersionInfo'
            async with AsyncClient(headers=headers) as client:
                version_response = await client.post(url=new_version_url)
                version_response.encoding = version_response.charset_encoding
                content = version_response.json()
                if content["errcode"] == "0":
                    version = content["version"]
                    title = content["versionname"]
                else:
                    return {
                        "status": 404,
                        "msg": "获取青年大学习失败！"
                    }
        openid = result[0]["openid"]
        cookie = result[0]["cookie"]
        headers.update({
            "Host": "qndxx.youth54.cn",
            "Connection": "keep-alive",
            "Accept": "*/*",
            "User-Agent": "Mozilla/5.0 (Linux; Android 12; M2007J3SC Build/SKQ1.220213.001; wv) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/86.0.4240.99 XWEB/3234 MMWEBSDK/20210902 Mobile Safari/537.36 MMWEBID/6170 MicroMessenger/8.0.15.2020(0x28000F30) Process/toolsmp WeChat/arm32 Weixin NetType/WIFI Language/zh_CN ABI/arm64",
            "X-Requested-With": "XMLHttpRequest",
            "Content-Type": "application/x-www-form-urlencoded; charset=UTF-8",
            "Origin": "http://qndxx.youth54.cn",
            "Referer": "http://qndxx.youth54.cn/SmartLA/dxx.w?method=pageSdtwdt",
            "Accept-Encoding": "gzip, deflate",
            "Accept-Language": "zh-CN,zh;q=0.9,en-US;q=0.8,en;q=0.7",
            "Cookie": cookie
        })
        try:
            async with AsyncClient(headers=headers) as client:
                data = {
                    'openid': openid,
                    'version': version
                }
                if not catalogue:
                    commit_url = 'http://qndxx.youth54.cn/SmartLA/dxxjfgl.w?method=studyLatest'
                else:
                    commit_url = "http://qndxx.youth54.cn/SmartLA/dxxjfgl.w?method=getLearnPastVersion"
                response = await client.post(url=commit_url, params=data, headers=headers)
                if response.status_code == 200:
                    response.encoding = response.charset_encoding
                    if response.json()["errcode"] == "0":
                        await User.filter(user_id=user_id).update(
                            commit_time=time.time(),
                            catalogue=title
                        )
                        await commit(user_id=user_id, catalogue=title, status=True)
                        return {
                            "status": 0,
                            "catalogue": title,
                            "msg": "提交成功！"
                        }
                    else:
                        await commit(user_id=user_id, catalogue=title, status=False)
                        return {
                            "status": 500,
                            "msg": "提交失败,cookie失效！"
                        }
                else:
                    await commit(user_id=user_id, catalogue=title, status=False)
                    return {
                        "status": 500,
                        "msg": "提交失败，cookie失效！"
                    }
        except Exception as e:
            await commit(user_id=user_id, catalogue=catalogue, status=False)
            return {
                "status": 500,
                "msg": f"提交失败,{e}"
            }


async def chongqing(user_id: int) -> dict:
    """
    重庆共青团
    :param user_id:
    :return:
    """
    result = await User.filter(user_id=user_id).values()
    if not result:
        return {
            "status": 500,
            "msg": "用户数据不存在！"
        }
    else:
        openid = result[0]["openid"]
        answer = await Answer.all().order_by("time").values()
        title = answer[-1]["catalogue"]
        headers.update(
            {
                "Host": "qndxx.cqyouths.com",
                "Connection": "keep-alive",
                "Accept": "application/json, text/plain, */*",
                "User-Agent": "Mozilla/5.0 (Linux; Android 12; M2007J3SC Build/SKQ1.220303.001; wv) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/86.0.4240.99 XWEB/3262 MMWEBSDK/20220204 Mobile Safari/537.36 MMWEBID/6170 MicroMessenger/8.0.20.2100(0x28001438) Process/toolsmp WeChat/arm32 Weixin NetType/WIFI Language/zh_CN ABI/arm64",
                "X-Requested-With": "com.tencent.mm",
                "Accept-Encoding": "gzip, deflate",
                "Accept-Language": "zh-CN,zh;q=0.9,en-US;q=0.8,en;q=0.7"
            }
        )
        try:
            new_url = f"http://qndxx.cqyouths.com/new_course.json?time={int(time.time())}"
            async with AsyncClient(headers=headers) as client:
                new_response = await client.get(url=new_url)
                if new_response.status_code == 200:
                    new_response.encoding = new_response.charset_encoding
                    course_id = new_response.json()['data'][0]['id']
                    commit_url = f"http://qndxx.cqyouths.com/api/course/studyCourse?openid={openid}&id={course_id}"
                    response = await client.get(url=commit_url)
                    if response.status_code == 200:
                        response.encoding = response.charset_encoding
                        if response.json()["status"] == 200:
                            await User.filter(user_id=user_id).update(
                                commit_time=time.time(),
                                catalogue=title
                            )
                            await commit(user_id=user_id, catalogue=title, status=True)
                            return {
                                "status": 0,
                                "catalogue": title,
                                "msg": "提交成功！"
                            }
                        elif response.json()["status"] == 201:
                            await User.filter(user_id=user_id).update(
                                commit_time=time.time(),
                                catalogue=title
                            )
                            await commit(user_id=user_id, catalogue=title, status=True)
                            return {
                                "status": 0,
                                "catalogue": title,
                                "msg": "提交成功！"
                            }
                        else:
                            await commit(user_id=user_id, catalogue=title, status=False)
                            return {
                                "status": 500,
                                "msg": "提交失败，openid错误！"
                            }
                    else:
                        await commit(user_id=user_id, catalogue=title, status=False)
                        return {
                            "status": 500,
                            "msg": "提交失败，openid错误！"
                        }
                else:
                    await commit(user_id=user_id, catalogue=title, status=False)
                    return {
                        "status": 500,
                        "msg": "提交失败，重庆共青团访问失败！"
                    }
        except Exception as e:
            logger.error(e)
            return {
                "status": 500,
                "msg": f"提交失败,{e}"
            }


async def jilin(user_id: int) -> dict:
    """
    吉青飞扬
    :param user_id:
    :return:
    """

    result = await User.filter(user_id=user_id).values()
    if not result:
        return {
            "status": 500,
            "msg": "用户数据不存在！"
        }
    else:
        openid = result[0]["openid"]
        dxx_id = result[0]["dxx_id"]
        answer = await Answer.all().order_by("time").values()
        title = answer[-1]["catalogue"]
        headers.update(
            {
                "Host": "jqfy.jl54.org",
                "Connection": "keep-alive",
                "Upgrade-Insecure-Requests": "1",
                "User-Agent": "Mozilla/5.0 (Linux; Android 12; M2007J3SC Build/SKQ1.220303.001; wv) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/86.0.4240.99 XWEB/3262 MMWEBSDK/20220204 Mobile Safari/537.36 MMWEBID/6170 MicroMessenger/8.0.20.2100(0x28001438) Process/toolsmp WeChat/arm32 Weixin NetType/WIFI Language/zh_CN ABI/arm64",
                "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/wxpic,image/tpg,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.9",
                "X-Requested-With": "com.tencent.mm",
                "Accept-Encoding": "gzip, deflate",
                "Accept-Language": "zh-CN,zh;q=0.9,en-US;q=0.8,en;q=0.7"
            }
        )
        try:
            commit_url = f"http://jqfy.jl54.org/jltw/wechat/editStudyRecord/{dxx_id}"
            data = {
                "openid": openid
            }
            async with AsyncClient(headers=headers) as client:
                response = await client.post(url=commit_url, params=data)
            if response.status_code == 200:
                response.encoding = response.charset_encoding
                if response.json()["code"] == '0001':
                    await User.filter(user_id=user_id).update(
                        commit_time=time.time(),
                        catalogue=title
                    )
                    await commit(user_id=user_id, catalogue=title, status=True)
                    return {
                        "status": 0,
                        "catalogue": title,
                        "msg": "提交成功！"
                    }
                else:
                    await commit(user_id=user_id, catalogue=title, status=False)
                    return {
                        "status": 500,
                        "msg": f"提交失败，openid错误！"
                    }
            else:
                await commit(user_id=user_id, catalogue=title, status=False)
                return {
                    "status": 500,
                    "msg": "提交失败，吉青飞扬访问失败！"
                }
        except Exception as e:
            logger.error(e)
            return {
                "status": 500,
                "msg": f"提交失败,{e}"
            }


async def guangdong(user_id: int) -> dict:
    """
    广东共青团
    :param user_id:用户ID
    :return:
    """

    result = await User.filter(user_id=user_id).values()
    if not result:
        return {
            "status": 500,
            "msg": "用户数据不存在！"
        }
    else:
        dxx_id = result[0]['dxx_id']
        token = result[0]["token"]
        answer = await Answer.all().order_by("time").values()
        try:
            study_headers = {
                'Host': 'youthstudy.12355.net',
                'Connection': 'keep-alive',
                'X-Litemall-Token': token,
                'X-Litemall-IdentiFication': 'young',
                'User-Agent': 'MicroMessenger',
                'Accept': '*/*',
                'Origin': 'https://youthstudy.12355.net',
                'X-Requested-With': 'com.tencent.mm',
                'Sec-Fetch-Site': 'same-origin',
                'Sec-Fetch-Mode': 'cors',
                'Sec-Fetch-Dest': 'empty',
                'Referer': 'https://youthstudy.12355.net/h5/',
                'Accept-Language': 'zh-CN,zh;q=0.9,en-US;q=0.8,en;q=0.7',
            }
            new_study_url = "https://youthstudy.12355.net/saomah5/api/young/chapter/new"
            async with AsyncClient(headers=study_headers, timeout=30, max_redirects=5) as client:
                study_response = await client.get(url=new_study_url)
            study_response.encoding = study_response.charset_encoding
            if study_response.json()["errno"] == 0:
                chapterId = study_response.json().get('data').get('entity').get('id')
                title = study_response.json().get('data').get('entity').get('name').replace('“青年大学习”', "").strip()
                commit_url = "https://youthstudy.12355.net/saomah5/api/young/course/chapter/saveHistory"
                async with AsyncClient(headers=study_headers, timeout=30, max_redirects=5) as client:
                    commit_response = await client.post(url=commit_url, data={
                        "chapterId": chapterId
                    })
                if commit_response.json()["errno"] == 0:
                    await User.filter(user_id=user_id).update(
                        token=token,
                        commit_time=time.time(),
                        catalogue=title
                    )
                    await commit(user_id=user_id, catalogue=title, status=True)
                    return {
                        "status": 0,
                        "catalogue": title,
                        "msg": "提交成功！"
                    }
                else:
                    await commit(user_id=user_id, catalogue=answer[-1]["catalogue"], status=False)
                    return {
                        "status": 500,
                        "msg": "提交失败！"
                    }
            else:
                token_headers = {
                    'Host': 'tuanapi.12355.net',
                    'Connection': 'keep-alive',
                    'Accept': 'application/json, text/javascript, */*; q=0.01',
                    'Origin': 'https://tuan.12355.net',
                    'User-Agent': 'MicroMessenger',
                    'X-Requested-With': 'com.tencent.mm',
                    'Sec-Fetch-Site': 'same-site',
                    'Sec-Fetch-Mode': 'cors',
                    'Referer': 'https://tuan.12355.net/wechat/view/YouthLearning/page.html',
                    'Accept-Encoding': 'gzip, deflate',
                    'Accept-Language': 'zh-CN,zh;q=0.9,en-US;q=0.8,en;q=0.7',
                }
                ger_param_url = f"https://tuanapi.12355.net/questionnaire/getYouthLearningUrl?mid={dxx_id}"
                async with AsyncClient(headers=token_headers, timeout=30, max_redirects=5) as client:
                    param_response = await client.get(url=ger_param_url)
                    if param_response.json()["status"] == 200:
                        content = param_response.json()["youthLearningUrl"].split("=")[-1]
                        token_url = "https://youthstudy.12355.net/apih5/api/user/get"
                        token_headers = {
                            'Host': 'youthstudy.12355.net',
                            'Connection': 'keep-alive',
                            'Content-Length': '134',
                            'Origin': 'https://youthstudy.12355.net',
                            'X-Litemall-Token': '',
                            'X-Litemall-IdentiFication': 'young',
                            'User-Agent': 'MicroMessenger',
                            'Content-Type': 'application/x-www-form-urlencoded',
                            'Accept': '*/*',
                            'X-Requested-With': 'com.tencent.mm',
                            'Sec-Fetch-Site': 'same-origin',
                            'Sec-Fetch-Mode': 'cors',
                            'Referer': 'https://youthstudy.12355.net/h5/',
                            'Accept-Encoding': 'gzip, deflate',
                            'Accept-Language': 'zh-CN,zh;q=0.9,en-US;q=0.8,en;q=0.7'
                        }
                        async with AsyncClient(headers=token_headers, timeout=30, max_redirects=5) as client:
                            token_response = await client.post(url=token_url,
                                                               data="sign=" + urllib.parse.quote(content))
                        if token_response.json()["errno"] == 0:
                            token = token_response.json()['data']['entity']['token']
                            study_headers = {
                                'Host': 'youthstudy.12355.net',
                                'Connection': 'keep-alive',
                                'X-Litemall-Token': token,
                                'X-Litemall-IdentiFication': 'young',
                                'User-Agent': 'MicroMessenger',
                                'Accept': '*/*',
                                'Origin': 'https://youthstudy.12355.net',
                                'X-Requested-With': 'com.tencent.mm',
                                'Sec-Fetch-Site': 'same-origin',
                                'Sec-Fetch-Mode': 'cors',
                                'Sec-Fetch-Dest': 'empty',
                                'Referer': 'https://youthstudy.12355.net/h5/',
                                'Accept-Language': 'zh-CN,zh;q=0.9,en-US;q=0.8,en;q=0.7',
                            }
                            new_study_url = "https://youthstudy.12355.net/saomah5/api/young/chapter/new"
                            async with AsyncClient(headers=study_headers, timeout=30, max_redirects=5) as client:
                                study_response = await client.get(url=new_study_url)
                            if study_response.json()["errno"] == 0:
                                chapterId = study_response.json().get('data').get('entity').get('id')
                                title = study_response.json().get('data').get('entity').get('name').replace(
                                    '"青年大学习”', "").strip()
                                commit_url = "https://youthstudy.12355.net/saomah5/api/young/course/chapter/saveHistory"
                                async with AsyncClient(headers=study_headers, timeout=30, max_redirects=5) as client:
                                    commit_response = await client.post(url=commit_url, data={
                                        "chapterId": chapterId
                                    })
                                if commit_response.json()["errno"] == 0:
                                    await User.filter(user_id=user_id).update(
                                        token=token,
                                        commit_time=time.time(),
                                        catalogue=title
                                    )
                                    await commit(user_id=user_id, catalogue=title, status=True)
                                    return {
                                        "status": 0,
                                        "catalogue": title,
                                        "msg": "提交成功！"
                                    }
                                else:
                                    await commit(user_id=user_id, catalogue=answer[-1]["catalogue"], status=False)
                                    return {
                                        "status": 500,
                                        "msg": "提交失败！"
                                    }
                        else:
                            await commit(user_id=user_id, catalogue=answer[-1]["catalogue"], status=False)
                            return {
                                "status": 500,
                                "msg": "提交失败，token获取失效！"
                            }
                    else:
                        await commit(user_id=user_id, catalogue=answer[-1]["catalogue"], status=False)
                        return {
                            "status": 500,
                            "msg": "提交失败，token获取失效！"
                        }
        except Exception as e:
            logger.error(e)
            await commit(user_id=user_id, catalogue=answer[-1]["catalogue"], status=False)
            return {
                "status": 500,
                "msg": "提交失败！"
            }


async def beijing(user_id: int) -> dict:
    """
    青春北京
    :param user_id:用户ID
    :return:
    """
    result = await User.filter(user_id=user_id).values()
    if not result:
        return {
            "status": 500,
            "msg": "用户数据不存在！"
        }
    else:
        cookie = result[0]['cookie']
        token = result[0]["token"]
        answer = await Answer.all().order_by("time").values()
        headers = {
            "User-Agent": "Mozilla/5.0 (iPhone; CPU iPhone OS 13_2_3 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/13.0.3 Mobile/15E148 Safari/604.1 Edg/113.0.0.0", }
        login_url = "https://m.bjyouth.net/site/login"
        try:
            async with AsyncClient(headers=headers) as client:
                login_rsp = await client.get(login_url)
                if login_rsp.status_code == 200:
                    login_rsp.encoding = login_rsp.charset_encoding
                    soup = BeautifulSoup(login_rsp.text, "lxml")
                    code_url = "https://m.bjyouth.net" + soup.select("#verifyCode-image")[0].get("src")
                    code_rsp = await client.get(code_url)
                    code_text = DdddOcr(show_ad=False).classification(code_rsp.content)
                    login_response = await client.post(
                        url=login_url,
                        data={
                            '_csrf_mobile': client.cookies['_csrf_mobile'],
                            'Login[password]': await encrypt(token),
                            'Login[username]': await encrypt(cookie),
                            'Login[verifyCode]': code_text
                        }
                    )
                    if login_response.status_code == 200:
                        login_response.encoding = login_response.charset_encoding
                        if login_response.text == '8':
                            await commit(user_id=user_id, catalogue=answer[-1]["catalogue"], status=False)
                            return {
                                "status": 500,
                                "msg": "提交失败，验证码识别失败！"
                            }
                        if 'fail' in login_response.text:
                            await commit(user_id=user_id, catalogue=answer[-1]["catalogue"], status=False)
                            return {
                                "status": 500,
                                "msg": "提交失败，账号或密码错误！"
                            }
                        course_url = "https://m.bjyouth.net/dxx/index"
                        course_rsp = await client.get(course_url)
                        if course_rsp.json()["code"] == 200:
                            title = course_rsp.json()['newCourse']['title']
                            courseId = course_rsp.json()['newCourse']['id']
                            organization_rsp = await client.get('https://m.bjyouth.net/dxx/is-league')
                            organization_id = int(organization_rsp.text)
                            study_url = "https://m.bjyouth.net/dxx/check"
                            study_response = await client.post(url=study_url, json={
                                "id": str(courseId),
                                "org_id": organization_id
                            })
                            if study_response.status_code == 200:
                                learnedInfo_url = 'https://m.bjyouth.net/dxx/my-study?page=1&limit=15&year=' + time.strftime(
                                    "%Y",
                                    time.localtime())
                                haveLearned = await client.get(learnedInfo_url)
                                if haveLearned.json()["code"] == 200:
                                    if f"学习课程：《{title}》" in list(
                                            map(lambda x: x['text'], haveLearned.json()['data'])):
                                        await User.filter(user_id=user_id).update(
                                            token=token,
                                            commit_time=time.time(),
                                            catalogue=answer[-1]["catalogue"]
                                        )
                                        await commit(user_id=user_id, catalogue=answer[-1]["catalogue"], status=True)
                                        return {
                                            "status": 0,
                                            "catalogue": answer[-1]["catalogue"],
                                            "msg": "提交成功！"
                                        }
                                    else:
                                        await commit(user_id=user_id, catalogue=answer[-1]["catalogue"], status=False)
                                        return {
                                            "status": 500,
                                            "msg": "提交失败！"
                                        }
                                else:
                                    await commit(user_id=user_id, catalogue=answer[-1]["catalogue"], status=False)
                                    return {
                                        "status": 500,
                                        "msg": "提交失败,获取历史提交信息失败！"
                                    }
                            else:
                                await commit(user_id=user_id, catalogue=answer[-1]["catalogue"], status=False)
                                return {
                                    "status": 500,
                                    "msg": "提交失败！"
                                }
                    else:
                        await commit(user_id=user_id, catalogue=answer[-1]["catalogue"], status=False)
                        return {
                            "status": 500,
                            "msg": "提交失败，登录失败！"
                        }
                else:
                    await commit(user_id=user_id, catalogue=answer[-1]["catalogue"], status=False)
                    return {
                        "status": 500,
                        "msg": "提交失败，北京共青团官网异常"
                    }
        except Exception as e:
            logger.error(e)
            await commit(user_id=user_id, catalogue=answer[-1]["catalogue"], status=False)
            return {
                "status": 500,
                "msg": f"提交失败,{e}"
            }


async def tianjin(user_id: int) -> dict:
    """
    津彩青春
    :param user_id:用户ID
    :return:
    """

    result = await User.filter(user_id=user_id).values()
    if not result:
        return {
            "status": 500,
            "msg": "用户数据不存在！"
        }
    else:
        cookie = result[0]["cookie"]
        answer = await Answer.all().order_by("time").values()
        title = answer[-1]["catalogue"]
        headers = {
            "User-Agent": "Mozilla/5.0 (iPhone; CPU iPhone OS 13_2_3 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/13.0.3 Mobile/15E148 Safari/604.1 Edg/113.0.0.0",
            "Cookie": cookie,
        }
        try:
            commit_url = "http://admin.ddy.tjyun.com/zm/jump/1"
            async with AsyncClient(headers=headers) as client:
                response = await client.get(url=commit_url)
            if response.status_code == 302:
                response.encoding = response.charset_encoding
                if "weui_text_area" not in response.text:
                    await User.filter(user_id=user_id).update(
                        commit_time=time.time(),
                        catalogue=title
                    )
                    await commit(user_id=user_id, catalogue=title, status=True)
                    return {
                        "status": 0,
                        "catalogue": title,
                        "msg": "提交成功！"
                    }
                else:
                    await commit(user_id=user_id, catalogue=title, status=False)
                    return {
                        "status": 500,
                        "msg": f"提交失败，Cookie失效！"
                    }
            else:
                await commit(user_id=user_id, catalogue=title, status=False)
                return {
                    "status": 500,
                    "msg": "提交失败，地址请求失败！"
                }
        except Exception as e:
            logger.error(e)
            return {
                "status": 500,
                "msg": f"提交失败,{e}"
            }


async def shanxi(user_id: int, catalogue: Optional[str] = None) -> dict:
    """
    三秦青年
    :param catalogue:
    :param user_id:用户ID
    :return:
    """
    result = await User.filter(user_id=user_id).values()
    if not result:
        return {
            "status": 500,
            "msg": "用户数据不存在！"
        }
    else:
        if catalogue:
            filterArg = {
                "name": catalogue
            }
            answer = await ShanXiDxx.filter(**filterArg).order_by("code").values()
            code = answer[-1]["code"]
            title = catalogue
        else:
            answer = await ShanXiDxx.all().order_by("code").values()
            code = answer[-1]["code"]
            title = answer[-1]["name"]
        token = result[0]["token"]
        headers = {
            "Host": "api.sxgqt.org.cn",
            "accept": "application/json",
            "x-requested-with": "XMLHttpRequest",
            "user-agent": "Mozilla/5.0 (Linux; Android 13; 23049RAD8C Build/TKQ1.221114.001; wv) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/111.0.5563.116 Mobile Safari/537.36 XWEB/5317 MMWEBSDK/20230701 MMWEBID/6170 MicroMessenger/8.0.40.2420(0x28002837) WeChat/arm64 Weixin NetType/WIFI Language/zh_CN ABI/arm64",
            "version": "H5_3.2.0",
            "token": token,
            "origin": "https://h5.sxgqt.org.cn"
        }
        try:
            commit_url = f"https://api.sxgqt.org.cn/h5sxapiv2/study/statistics?type=new&id={code}"
            async with AsyncClient(headers=headers) as client:
                response = await client.get(url=commit_url)
                if response.status_code == 200:
                    if response.json()["code"] == 0:
                        await User.filter(user_id=user_id).update(
                            commit_time=time.time(),
                            catalogue=title
                        )
                        await commit(user_id=user_id, catalogue=title, status=True)
                        return {
                            "status": 0,
                            "catalogue": title,
                            "msg": "提交成功！"
                        }
                    else:
                        await commit(user_id=user_id, catalogue=title, status=False)
                        return {
                            "status": 500,
                            "msg": f"提交失败，token失效！"
                        }
                else:
                    await commit(user_id=user_id, catalogue=title, status=False)
                    return {
                        "status": 500,
                        "msg": "提交失败，地址请求失败！"
                    }
        except Exception as e:
            logger.error(e)
            await commit(user_id=user_id, catalogue=title, status=False)
            return {
                "status": 500,
                "msg": f"提交失败,{e}"
            }



import asyncio
import datetime

import psutil
from nonebot import get_bot, get_driver

from ...models.accuont import User
from ...models.dxx import PushList, Answer, Area
from ...utils.path import getConfig

DRIVER = get_driver()
start_time: str = ""


async def get_status():
    status_result = {
    }
    try:
        status_result['start_time'] = start_time
    except Exception:
        status_result['start_time'] = '未知'
    try:
        bot = get_bot()
        bot_info = await bot.get_login_info()
        status_result['bot_id'] = bot_info['user_id']
        status_result['nickname'] = bot_info['nickname']
        bot_friends = await bot.get_friend_list()
        bot_groups = await bot.get_group_list()
        status_result['friend_count'] = len(bot_friends)
        status_result['group_count'] = len(bot_groups)
        status_result['user_count'] = await User.all().count()
        status_result['area_count'] = await Area.all().count()
        answer = await Answer.all().order_by("time").values()
        title = answer[-1]["catalogue"]
        setting = getConfig()
        status_result["ip"] = setting["DXX_IP"]
        status_result['catalogue'] = title
        status_result['notice_count'] = await PushList.all().count()
    except Exception:
        status_result['bot_id'] = '未知'
        status_result['msg_received'] = '未知'
        status_result['msg_sent'] = '未知'

    status_result['system_start_time'] = datetime.datetime.fromtimestamp(psutil.boot_time()).strftime(
        "%Y-%m-%d %H:%M:%S")

    psutil.cpu_percent()
    await asyncio.sleep(0.1)
    cpu_percent = psutil.cpu_percent()
    # cpu_count = psutil.cpu_count(logical=False)
    # cpu_count_logical = psutil.cpu_count()
    # cpu_freq = psutil.cpu_freq()
    ram_stat = psutil.virtual_memory()
    swap_stat = psutil.swap_memory()
    status_result['cpu_percent'] = f'{cpu_percent}%'
    status_result['ram_percent'] = f'{ram_stat.percent}%'
    status_result['swap_percent'] = f'{swap_stat.percent}%'

    return status_result


@DRIVER.on_startup
async def start_up():
    global start_time
    start_time = datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S')



import json
import re
import secrets
import time
import urllib.parse
from urllib.parse import parse_qs, urlparse

from bs4 import BeautifulSoup
from ddddocr import DdddOcr
from fastapi import APIRouter
from fastapi.responses import HTMLResponse, JSONResponse, RedirectResponse
from httpx import AsyncClient
from nonebot import logger

from ..pages.add import hubei_page, jiangxi_page, anhui_page, sichuan_page, shandong_page, \
    chongqing_page, jilin_page, guangdong_page, beijing_page, tianjin_page, shanxi_page
from ..utils.add import write_to_database
from ...models.accuont import User, AddUser
from ...utils.utils import encrypt

route = APIRouter()


@route.post("/add", response_class=JSONResponse)
async def add(data: dict) -> JSONResponse:
    user_id = data["user_id"]
    if await User.filter(user_id=user_id).count():
        return JSONResponse({
            "status": 0,
            "msg": "添加失败！，用户信息存在！"
        })
    else:
        status = await write_to_database(data=data)
        if status:
            return JSONResponse(
                {
                    "status": 0,
                    "msg": "添加成功！"
                }
            )
        else:
            return JSONResponse({
                "status": 500,
                "msg": "添加失败！"
            })


@route.get("/hubei", response_class=HTMLResponse)
async def hubei(user_id: int, group_id: int):
    result = await AddUser.filter(user_id=user_id, group_id=group_id, status="未通过").count()
    if result:
        return hubei_page.render(
            site_title='青春湖北 | TeenStudy',
            site_icon="https://img1.imgtp.com/2023/10/06/NChUNeiA.png"
        )
    return RedirectResponse(
        url="/TeenStudy/login"
    )


@route.get("/jiangxi", response_class=HTMLResponse)
async def jiangxi(user_id: int, group_id: int):
    result = await AddUser.filter(user_id=user_id, group_id=group_id, status="未通过").count()
    if result:
        return jiangxi_page.render(
            site_title='江西共青团 | TeenStudy',
            site_icon="https://img1.imgtp.com/2023/10/06/NChUNeiA.png"
        )
    return RedirectResponse(
        url="/TeenStudy/login"
    )


@route.post("/jiangxi/add", response_class=JSONResponse)
async def anhui_add(data: dict) -> JSONResponse:
    user_id = data["user_id"]
    if await User.filter(user_id=user_id).count():
        return JSONResponse({
            "status": 500,
            "msg": "添加失败！，用户信息存在！"
        })
    else:
        url = data["url"]
        parsed_url = urlparse(url)
        query = parse_qs(parsed_url.query)
        openid = query.get('openid')
        if openid:
            openid = openid[0]
        else:
            return JSONResponse({
                "status": 404,
                "msg": "openid获取失败，请检查连接中是否含有openid"
            })
        url = f"http://www.jxqingtuan.cn/pub/pub/vol/member/info?accessToken={openid}"
        headers = {
            'User-Agent': 'Mozilla/5.0 (Linux; Android 12; M2007J3SC Build/SKQ1.220213.001; wv) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/86.0.4240.99 XWEB/3234 MMWEBSDK/20210902 Mobile Safari/537.36 MMWEBID/6170 MicroMessenger/8.0.15.2020(0x28000F30) Process/toolsmp WeChat/arm32 Weixin NetType/WIFI Language/zh_CN ABI/arm64',
            'Accept': '*/*',
            'Host': 'www.jxqingtuan.cn',
            'Connection': 'keep-alive',
            'Cookie': 'JSESSIONID=' + secrets.token_urlsafe(40)
        }
        try:
            async with AsyncClient(headers=headers, timeout=30, max_redirects=5) as client:
                response = await client.get(url=url)
                if response.status_code == 200 and response.json().get("code") == "200":
                    data["name"] = response.json()["vo"]["username"]
                    data["gender"] = response.json()["vo"]["sex"]
                    data["mobile"] = response.json()["vo"]["telphone"]
                    data["area"] = "江西"
                    data["leader"] = None
                    data["openid"] = response.json()["vo"]["openid"]
                    data["dxx_id"] = response.json()["vo"]["areaid4"]
                    data["university_type"] = None
                    data["university_id"] = response.json()["vo"]["areaid1"]
                    data["university"] = response.json()["vo"]["danwei"].split("-")[1]
                    data["college_id"] = response.json()["vo"]["areaid2"]
                    data["college"] = response.json()["vo"]["danwei"].split("-")[0]
                    data["organization_id"] = response.json()["vo"]["areaid3"]
                    data["organization"] = response.json()["vo"]["zhibu"]
                    data["token"] = response.json()["vo"]["id"]
                    if not data["dxx_id"]:
                        data["dxx_id"] = data["college_id"] + "0000"
                    data.pop("url")
                    status = await write_to_database(data=data)
                    if status:
                        return JSONResponse(
                            {
                                "status": 0,
                                "msg": "添加成功！"
                            }
                        )
                    else:
                        return JSONResponse({
                            "status": 500,
                            "msg": "添加失败！"
                        })
                else:
                    return JSONResponse({
                        "status": 500,
                        "msg": "添加失败！"
                    })
        except Exception as e:
            return JSONResponse({
                "status": 500,
                "msg": f"添加失败!{e}"
            })


@route.get("/shanghai/{user_id}/{group_id}", response_class=HTMLResponse)
async def shanghai(user_id: int, group_id: int, appid: str, openid: str, nickname: str, headimg: str, t: str):
    result = await AddUser.filter(user_id=user_id, group_id=group_id, status="未通过").count()
    if result:
        headers = {
            "Host": "qcsh.h5yunban.com",
            "Connection": "keep-alive",
            "Accept": "application/json, text/javascript, */*; q=0.01",
            "X-Requested-With": "XMLHttpRequest",
            "User-Agent": "Mozilla/5.0 (Linux; Android 12; M2007J3SC Build/SKQ1.220303.001; wv) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/86.0.4240.99 XWEB/3262 MMWEBSDK/20220204 Mobile Safari/537.36 MMWEBID/6170 MicroMessenger/8.0.20.2100(0x28001438) Process/toolsmp WeChat/arm32 Weixin NetType/WIFI Language/zh_CN ABI/arm64",
            "Content-Type": "application/json;charset=UTF-8",
            "Sec-Fetch-Site": "same-origin",
            "Sec-Fetch-Mode": "cors",
            "Sec-Fetch-Dest": "empty",
            "Referer": "https://qcsh.h5yunban.com/youth-learning/signUp.php?rv=2020",
            "Accept-Encoding": "gzip, deflate",
            "Accept-Language": "zh-CN,zh;q=0.9,en-US;q=0.8,en;q=0.7",
        }
        url = f"https://qcsh.h5yunban.com/youth-learning/cgi-bin/login/we-chat/callback?appid=wxa693f4127cc93fad&openid={openid}&nickname={nickname}&headimg={headimg}&callback=https://qcsh.h5yunban.com/youth-learning/&scope=snsapi_userinfo"
        async with AsyncClient(headers=headers) as client:
            response = await client.get(url)
        response.encoding = response.charset_encoding
        accessToken = re.findall(r"\(\'accessToken\'\,\s+\'(.+?)\'\)", response.text)[0]
        url = f"https://qcsh.h5yunban.com/youth-learning/cgi-bin/user-api/course/last-info?accessToken={accessToken}"
        async with AsyncClient(headers=headers) as client:
            response = await client.get(url)
        response.encoding = response.charset_encoding
        result = response.json()
        if result["status"] == 200:
            try:
                data = {"dxx_id": result["result"]["nid"], "name": result["result"]["cardNo"], "user_id": user_id,
                        "group_id": group_id, "area": "上海", "openid": openid, "token": nickname, "cookie": headimg,
                        "mobile": result["result"]["subOrg"], "password": ""}
                for item in result["result"]["nodes"]:
                    if len(item["id"]) <= 5:
                        data["university_type"] = item["id"]
                    if len(item["id"]) <= 9:
                        data["university_id"] = item["id"]
                        data["university"] = item["title"]
                    if len(item["id"]) <= 13:
                        data["college_id"] = item["id"]
                        data["college"] = item["title"]
                    if len(item["id"]) <= 17:
                        data["organization_id"] = item["id"]
                        data["organization"] = item["title"]
            except Exception as e:
                return JSONResponse({"status": 500, "msg": f"请选择好个人信息再重新扫码,错误信息：{e}"})
            status = await write_to_database(data=data)
            if status:
                return JSONResponse(
                    {
                        "status": 0,
                        "msg": "添加成功！"
                    }
                )
            else:
                return JSONResponse({
                    "status": 500,
                    "msg": "添加失败！"
                })

    return RedirectResponse(
        url="/TeenStudy/login"
    )


@route.get("/zhejiang/{user_id}/{group_id}", response_class=HTMLResponse)
async def zhejiang(user_id: int, group_id: int, appid: str, openid: str, nickname: str, headimg: str, t: str):
    result = await AddUser.filter(user_id=user_id, group_id=group_id, status="未通过").count()
    if result:
        headers = {
            "Host": "qczj.h5yunban.com",
            "Connection": "keep-alive",
            "Accept": "application/json, text/javascript, */*; q=0.01",
            "X-Requested-With": "XMLHttpRequest",
            "User-Agent": "Mozilla/5.0 (Linux; Android 12; M2007J3SC Build/SKQ1.220303.001; wv) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/86.0.4240.99 XWEB/3262 MMWEBSDK/20220204 Mobile Safari/537.36 MMWEBID/6170 MicroMessenger/8.0.20.2100(0x28001438) Process/toolsmp WeChat/arm32 Weixin NetType/WIFI Language/zh_CN ABI/arm64",
            "Content-Type": "application/json;charset=UTF-8",
            "Sec-Fetch-Site": "same-origin",
            "Sec-Fetch-Mode": "cors",
            "Sec-Fetch-Dest": "empty",
            "Accept-Encoding": "gzip, deflate",
            "Accept-Language": "zh-CN,zh;q=0.9,en-US;q=0.8,en;q=0.7",
        }
        url = f"https://qczj.h5yunban.com/qczj-youth-learning/cgi-bin/login/we-chat/callback?callback=https%3A%2F%2Fqczj.h5yunban.com%2Fqczj-youth-learning%2Findex.php&scope=snsapi_userinfo&appid=wx56b888a1409a2920&openid={openid}&nickname={nickname}&headimg={headimg}&time={int(time.time())}&source=common&sign=&t={int(time.time())}"
        async with AsyncClient(headers=headers) as client:
            response = await client.get(url)
        response.encoding = response.charset_encoding
        accessToken = re.findall(r"\(\'accessToken\'\,\s+\'(.+?)\'\)", response.text)[0]
        url = f"https://qczj.h5yunban.com/qczj-youth-learning/cgi-bin/user-api/course/last-info?accessToken={accessToken}"
        async with AsyncClient(headers=headers) as client:
            response = await client.get(url)
        response.encoding = response.charset_encoding
        result = response.json()
        if result["status"] == 200:
            try:
                data = {"dxx_id": result["result"]["nid"], "name": result["result"]["cardNo"], "user_id": user_id,
                        "group_id": group_id, "area": "浙江", "openid": openid, "token": nickname, "cookie": headimg,
                        "mobile": result["result"]["subOrg"], "password": ""}
                for item in result["result"]["nodes"]:
                    if len(item["id"]) <= 5:
                        data["university_type"] = item["id"]
                    if len(item["id"]) <= 9:
                        data["university_id"] = item["id"]
                        data["university"] = item["title"]
                    if len(item["id"]) <= 13:
                        data["college_id"] = item["id"]
                        data["college"] = item["title"]
                    if len(item["id"]) <= 17:
                        data["organization_id"] = item["id"]
                        data["organization"] = item["title"]
            except Exception as e:
                return JSONResponse({
                    "status": 500,
                    "msg": f"请选择好个人信息再扫码,错误信息：{e}"
                })
            status = await write_to_database(data=data)
            if status:
                return JSONResponse(
                    {
                        "status": 0,
                        "msg": "添加成功！"
                    }
                )
            else:
                return JSONResponse({
                    "status": 500,
                    "msg": "添加失败！"
                })
    return RedirectResponse(
        url="/TeenStudy/login"
    )


@route.post("/anhui/add", response_class=JSONResponse)
async def anhui_add(data: dict) -> JSONResponse:
    user_id = data["user_id"]
    if await User.filter(user_id=user_id).count():
        return JSONResponse({
            "status": 0,
            "msg": "添加失败！，用户信息存在！"
        })
    else:
        url = data["url"]
        token = url.split("=")[-1]
        headers = {
            "Host": "dxx.ahyouth.org.cn",
            "Accept": "application/json, text/plain, */*",
            "User-Agent": "Mozilla/5.0 (Linux; Android 12; M2007J3SC Build/SKQ1.220213.001; wv) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/86.0.4240.99 XWEB/3234 MMWEBSDK/20210902 Mobile Safari/537.36 MMWEBID/6170 MicroMessenger/8.0.15.2020(0x28000F30) Process/toolsmp WeChat/arm32 Weixin NetType/WIFI Language/zh_CN ABI/arm64",
            "Accept-Language": "zh-CN,zh;q=0.9,en-US;q=0.8,en;q=0.7",
            "Referer": "http://dxx.ahyouth.org.cn/",
            "Accept-Encoding": "gzip, deflate",
            "Connection": "keep-alive",
            'Content-Type': 'application/x-www-form-urlencoded',
            "X-Requested-With": 'com.tencent.mm',
            "Origin": 'http://dxx.ahyouth.org.cn',
            "token": token
        }
        try:
            async with AsyncClient(headers=headers) as client:
                response = await client.get(url=url)
            response.encoding = response.charset_encoding
            start = "//从数据库调用"
            end = "this.level1 = one"
            start = response.text.find(start) + 8
            end = response.text.find(end)
            content = response.text[start:end].strip().split("\n")
            username = content[0].split("=")[-1].replace('"', "").strip()
            gender = content[1].split("=")[-1].replace('"', "").strip()
            mobile = content[2].split("=")[-1].replace('"', "").strip()
            level1 = content[3].split("=")[-1].replace('"', "").strip()
            level2 = content[4].split("=")[-1].replace('"', "").strip()
            level3 = content[5].split("=")[-1].replace('"', "").strip()
            level4 = content[6].split("=")[-1].replace('"', "").strip()
            level5 = content[7].split("=")[-1].replace('"', "").strip()
            if level5 == "默认":
                level5 = ""
            params = {
                'username': username,
                'gender': gender,
                'mobile': mobile,
                'level1': level1,
                'level2': level2,
                'level3': level3,
                'level4': level4,
                'level5': level5
            }
            get_infor_url = 'http://dxx.ahyouth.org.cn/api/saveUserInfo'
            async with AsyncClient(headers=headers, timeout=30, max_redirects=5) as client:
                infor_response = await client.post(url=get_infor_url, params=params)
            infor_response.encoding = infor_response.charset_encoding
            infor_response_json = infor_response.json()
            if infor_response_json['code'] == 200:
                data["name"] = infor_response_json['content']['username']
                data["token"] = infor_response_json['content']['token']
                data["gender"] = infor_response_json['content']['gender']
                data["mobile"] = infor_response_json['content']['mobile']
                data['university_type'] = infor_response_json['content']['level1']
                data['university'] = infor_response_json['content']['level2']
                data['college'] = infor_response_json['content']['level3']
                data['organization'] = infor_response_json['content']['level4']
                data['organization_id'] = infor_response_json['content']['level5']
                data["openid"] = infor_response_json["content"]["openid"]
                data["dxx_id"] = infor_response_json["content"]["id"]
                data.pop("url")
                status = await write_to_database(data=data)
                if status:
                    return JSONResponse(
                        {
                            "status": 0,
                            "msg": "添加成功！"
                        }
                    )
                else:
                    return JSONResponse({
                        "status": 500,
                        "msg": "添加失败！"
                    })
            else:
                return JSONResponse({
                    "status": 500,
                    "msg": "添加失败！"
                })
        except Exception as e:
            return JSONResponse({
                "status": 500,
                "msg": f"添加失败!{e}"
            })


@route.get("/anhui", response_class=HTMLResponse)
async def jiangsu(user_id: int, group_id: int):
    result = await AddUser.filter(user_id=user_id, group_id=group_id, status="未通过").count()
    if result:
        return anhui_page.render(
            site_title='安徽共青团 | TeenStudy',
            site_icon="https://img1.imgtp.com/2023/10/06/NChUNeiA.png"
        )
    return RedirectResponse(
        url="/TeenStudy/login"
    )


@route.post("/sichuan/add", response_class=HTMLResponse)
async def sichuan_add(result: dict) -> JSONResponse:
    user_id = result["user_id"]
    if await User.filter(user_id=user_id).count():
        return JSONResponse({
            "status": 0,
            "msg": "添加失败！，用户信息存在！"
        })
    else:
        try:
            data = {"name": result["name"], "mobile": result["mobile"], "dxx_id": result["org"].split("#")[1],
                    "university_type": result["allOrgName"].split("#")[1], "university_id": result["org"].split("#")[2],
                    "university": result["allOrgName"].split("#")[2], "college_id": result["org"].split("#")[3],
                    "college": result["allOrgName"].split("#")[3], "organization_id": result["org"].split("#")[4],
                    "organization": result["allOrgName"].split("#")[4], "password": result["password"], "area": "四川",
                    "group_id": result["group_id"], "user_id": result["user_id"], "token": result["token"]}
            status = await write_to_database(data=data)
            if status:
                return JSONResponse(
                    {
                        "status": 0,
                        "msg": "添加成功！"
                    }
                )
            else:
                return JSONResponse({
                    "status": 500,
                    "msg": "添加失败！"
                })
        except Exception as e:
            return JSONResponse({
                "status": 500,
                "msg": f"添加失败,{e}"
            })


@route.get("/sichuan", response_class=HTMLResponse)
async def sichuan(user_id: int, group_id: int):
    result = await AddUser.filter(user_id=user_id, group_id=group_id, status="未通过").count()
    if result:
        return sichuan_page.render(
            site_title='天府新青年 | TeenStudy',
            site_icon="https://img1.imgtp.com/2023/10/06/NChUNeiA.png"
        )
    return RedirectResponse(
        url="/TeenStudy/login"
    )


@route.post("/shandong/add", response_class=HTMLResponse)
async def shandong_add(data: dict) -> JSONResponse:
    user_id = data["user_id"]
    if await User.filter(user_id=user_id).count():
        return JSONResponse({
            "status": 0,
            "msg": "添加失败！，用户信息存在！"
        })
    else:
        try:
            openid = data["openid"]
            cookie = data["cookie"]
            headers = {
                "Host": "qndxx.youth54.cn",
                "Connection": "keep-alive",
                "Accept": "*/*",
                "User-Agent": "Mozilla/5.0 (Linux; Android 12; M2007J3SC Build/SKQ1.220213.001; wv) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/86.0.4240.99 XWEB/3234 MMWEBSDK/20210902 Mobile Safari/537.36 MMWEBID/6170 MicroMessenger/8.0.15.2020(0x28000F30) Process/toolsmp WeChat/arm32 Weixin NetType/WIFI Language/zh_CN ABI/arm64",
                "X-Requested-With": "XMLHttpRequest",
                "Content-Type": "application/x-www-form-urlencoded; charset=UTF-8",
                "Origin": "http://qndxx.youth54.cn",
                "Referer": "http://qndxx.youth54.cn/SmartLA/dxx.w?method=enterIndexPage&fxopenid=&fxversion=",
                "Accept-Encoding": "gzip, deflate",
                "Accept-Language": "zh-CN,zh;q=0.9,en-US;q=0.8,en;q=0.7",
                "Cookie": cookie
            }
            url = "http://qndxx.youth54.cn/SmartLA/dxxjfgl.w?method=getUserBasicInfo"
            data_json = {
                "openid": openid
            }
            async with AsyncClient(headers=headers) as client:
                response = await client.post(url=url, params=data_json)
            if response.status_code == 200:
                response.encoding = response.charset_encoding
                content = response.json()
                if content["errcode"] == "0":
                    data["mobile"] = content["sjh"]
                    data["name"] = content["xm"]
                    data["organization"] = content["tzzmc"]
                    data["organization_id"] = content["tzzbh"]
                    data["university_type"] = content["tzzxx"].split(",")[0]
                    data["university"] = content["tzzxx"].split(",")[1]
                    data["college"] = content["tzzxx"].split(",")[2]
                    status = await write_to_database(data=data)
                    if status:
                        return JSONResponse(
                            {
                                "status": 0,
                                "msg": "添加成功！"
                            }
                        )
                    else:
                        return JSONResponse({
                            "status": 500,
                            "msg": "添加失败！"
                        })
                else:
                    return JSONResponse({"status": 500, "msg": "添加失败！"})
            else:
                return JSONResponse({"status": 500, "msg": "添加失败！"})
        except Exception as e:
            return JSONResponse({
                "status": 500,
                "msg": f"添加失败,{e}"
            })


@route.get("/shandong", response_class=HTMLResponse)
async def shandong(user_id: int, group_id: int):
    result = await AddUser.filter(user_id=user_id, group_id=group_id, status="未通过").count()
    if result:
        return shandong_page.render(
            site_title='青春山东 | TeenStudy',
            site_icon="https://img1.imgtp.com/2023/10/06/NChUNeiA.png"
        )
    return RedirectResponse(
        url="/TeenStudy/login"
    )


@route.post("/chongqing/add", response_class=HTMLResponse)
async def chongqing_add(data: dict) -> JSONResponse:
    user_id = data["user_id"]
    if await User.filter(user_id=user_id).count():
        return JSONResponse({
            "status": 0,
            "msg": "添加失败！，用户信息存在！"
        })
    else:
        try:
            openid = data["openid"]
            headers = {
                "Host": "qndxx.cqyouths.com",
                "Connection": "keep-alive",
                "Accept": "application/json, text/plain, */*",
                "User-Agent": "Mozilla/5.0 (Linux; Android 12; M2007J3SC Build/SKQ1.220303.001; wv) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/86.0.4240.99 XWEB/3262 MMWEBSDK/20220204 Mobile Safari/537.36 MMWEBID/6170 MicroMessenger/8.0.20.2100(0x28001438) Process/toolsmp WeChat/arm32 Weixin NetType/WIFI Language/zh_CN ABI/arm64",
                "X-Requested-With": "com.tencent.mm",
                "Accept-Encoding": "gzip, deflate",
                "Accept-Language": "zh-CN,zh;q=0.9,en-US;q=0.8,en;q=0.7"
            }
            url = f"http://qndxx.cqyouths.com/api/user/userInfo?openid={openid}"
            async with AsyncClient(headers=headers) as client:
                response = await client.get(url=url)
            if response.status_code == 200:
                response.encoding = response.charset_encoding
                content = response.json()
                if content["status"] == 200:
                    data["mobile"] = content["data"]["mobile"]
                    data["name"] = content["data"]["real_name"]
                    data["organization"] = content["data"]["user_league_name"]["name4"] + \
                                           content["data"]["user_league_name"]["name5"]
                    data["organization_id"] = content["data"]["league_id"]
                    data["university_type"] = content["data"]["user_league_name"]["name1"]
                    data["university"] = content["data"]["user_league_name"]["name2"]
                    data["college"] = content["data"]["user_league_name"]["name3"]
                    data["college_id"] = content["data"]["league_id4"]
                    data["university_id"] = content["data"]["league_id2"]
                    status = await write_to_database(data=data)
                    if status:
                        return JSONResponse(
                            {
                                "status": 0,
                                "msg": "添加成功！"
                            }
                        )
                    else:
                        return JSONResponse({
                            "status": 500,
                            "msg": "添加失败！"
                        })
                else:
                    return JSONResponse({"status": 500, "msg": "添加失败！"})
            else:
                return JSONResponse({"status": 500, "msg": "添加失败！"})
        except Exception as e:
            return JSONResponse({
                "status": 500,
                "msg": f"添加失败,{e}"
            })


@route.get("/chongqing", response_class=HTMLResponse)
async def chongqing(user_id: int, group_id: int):
    result = await AddUser.filter(user_id=user_id, group_id=group_id, status="未通过").count()
    if result:
        return chongqing_page.render(
            site_title='重庆共青团 | TeenStudy',
            site_icon="https://img1.imgtp.com/2023/10/06/NChUNeiA.png"
        )
    return RedirectResponse(
        url="/TeenStudy/login"
    )


@route.post("/jilin/add", response_class=HTMLResponse)
async def jilin_add(data: dict) -> JSONResponse:
    user_id = data["user_id"]
    if await User.filter(user_id=user_id).count():
        return JSONResponse({
            "status": 500,
            "msg": "添加失败！，用户信息存在！"
        })
    else:
        try:
            openid = data["openid"]
            headers = {
                "Host": "jqfy.jl54.org",
                "Connection": "keep-alive",
                "Upgrade-Insecure-Requests": "1",
                "User-Agent": "Mozilla/5.0 (Linux; Android 12; M2007J3SC Build/SKQ1.220303.001; wv) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/86.0.4240.99 XWEB/3262 MMWEBSDK/20220204 Mobile Safari/537.36 MMWEBID/6170 MicroMessenger/8.0.20.2100(0x28001438) Process/toolsmp WeChat/arm32 Weixin NetType/WIFI Language/zh_CN ABI/arm64",
                "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/wxpic,image/tpg,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.9",
                "X-Requested-With": "com.tencent.mm",
                "Accept-Encoding": "gzip, deflate",
                "Accept-Language": "zh-CN,zh;q=0.9,en-US;q=0.8,en;q=0.7"
            }
            url = "http://jqfy.jl54.org/jltw/wechat/updateStudentInfo"
            params = {
                "openid_u": openid
            }
            async with AsyncClient(headers=headers) as client:
                response = await client.post(url=url, params=params)
            if response.status_code == 200:
                response.encoding = response.charset_encoding
                start = "var studentInfo ="
                end = 'var ctxPath = "\/jltw\/"'
                content = json.loads(
                    response.text[response.text.find(start):response.text.find(end)].split("=")[-1].replace(";",
                                                                                                            "").strip())
                data["mobile"] = content["telNum"]
                data["name"] = content["name"]
                data["organization_id"] = content["typeInfoId"]
                data["dxx_id"] = content["id"]
                data["gender"] = content["sex"]
                status = await write_to_database(data=data)
                if status:
                    return JSONResponse(
                        {
                            "status": 0,
                            "msg": "添加成功！"
                        }
                    )
                else:
                    return JSONResponse({
                        "status": 500,
                        "msg": "添加失败！"
                    })
            else:
                return JSONResponse({"status": 500, "msg": "添加失败！"})
        except Exception as e:
            return JSONResponse({
                "status": 500,
                "msg": f"添加失败,{e}"
            })


@route.get("/jilin", response_class=HTMLResponse)
async def jilin(user_id: int, group_id: int):
    result = await AddUser.filter(user_id=user_id, group_id=group_id, status="未通过").count()
    if result:
        return jilin_page.render(
            site_title='吉青飞扬 | TeenStudy',
            site_icon="https://img1.imgtp.com/2023/10/06/NChUNeiA.png"
        )
    return RedirectResponse(
        url="/TeenStudy/login"
    )


@route.post("/guangdong/add", response_class=HTMLResponse)
async def guangdong_add(data: dict) -> JSONResponse:
    user_id = data["user_id"]
    if await User.filter(user_id=user_id).count():
        return JSONResponse({
            "status": 500,
            "msg": "添加失败！，用户信息存在！"
        })
    else:
        try:
            url = data["url"]
            dxx_id = re.findall(r"memberId=(.*?)&showMemberAdditionNames", url)[0]
            token_headers = {
                'Host': 'tuanapi.12355.net',
                'Connection': 'keep-alive',
                'Accept': 'application/json, text/javascript, */*; q=0.01',
                'Origin': 'https://tuan.12355.net',
                'User-Agent': 'MicroMessenger',
                'X-Requested-With': 'com.tencent.mm',
                'Sec-Fetch-Site': 'same-site',
                'Sec-Fetch-Mode': 'cors',
                'Referer': 'https://tuan.12355.net/wechat/view/YouthLearning/page.html',
                'Accept-Encoding': 'gzip, deflate',
                'Accept-Language': 'zh-CN,zh;q=0.9,en-US;q=0.8,en;q=0.7',
            }
            ger_param_url = f"https://tuanapi.12355.net/questionnaire/getYouthLearningUrl?mid={dxx_id}"
            async with AsyncClient(headers=token_headers, timeout=30, max_redirects=5) as client:
                param_response = await client.get(url=ger_param_url)
                if param_response.json()["status"] == 200:
                    content = param_response.json()["youthLearningUrl"].split("=")[-1]
                    token_url = "https://youthstudy.12355.net/apih5/api/user/get"
                    token_headers = {
                        'Host': 'youthstudy.12355.net',
                        'Connection': 'keep-alive',
                        'Origin': 'https://youthstudy.12355.net',
                        'X-Litemall-Token': '',
                        'X-Litemall-IdentiFication': 'young',
                        'User-Agent': 'MicroMessenger',
                        'Content-Type': 'application/x-www-form-urlencoded',
                        'Accept': '*/*',
                        'X-Requested-With': 'com.tencent.mm',
                        'Sec-Fetch-Site': 'same-origin',
                        'Sec-Fetch-Mode': 'cors',
                        'Referer': 'https://youthstudy.12355.net/h5/',
                        'Accept-Encoding': 'gzip, deflate',
                        'Accept-Language': 'zh-CN,zh;q=0.9,en-US;q=0.8,en;q=0.7'
                    }
                    async with AsyncClient(headers=token_headers, timeout=30, max_redirects=5) as client:
                        token_response = await client.post(url=token_url, data="sign=" + urllib.parse.quote(content))
                    if token_response.json()["errno"] == 0:
                        token = token_response.json()['data']['entity']['token']
                        name = token_response.json()['data']['entity']['nickName']
                        organization_id = token_response.json()['data']['entity']['organizeId']
                        data["name"] = name
                        data["organization_id"] = organization_id
                        data["dxx_id"] = dxx_id
                        data["token"] = token
                        data.pop("url")
                        status = await write_to_database(data=data)
                        if status:
                            return JSONResponse(
                                {
                                    "status": 0,
                                    "msg": "添加成功！"
                                }
                            )
                        else:
                            return JSONResponse({
                                "status": 500,
                                "msg": "添加失败！"
                            })
                    else:
                        return JSONResponse({"status": 500, "msg": "添加失败！"})
                else:
                    return JSONResponse({"status": 500, "msg": "添加失败！"})
        except Exception as e:
            return JSONResponse({
                "status": 500,
                "msg": f"添加失败,{e}"
            })


@route.get("/guangdong", response_class=HTMLResponse)
async def guangdong(user_id: int, group_id: int):
    result = await AddUser.filter(user_id=user_id, group_id=group_id, status="未通过").count()
    if result:
        return guangdong_page.render(
            site_title='广东共青团 | TeenStudy',
            site_icon="https://img1.imgtp.com/2023/10/06/NChUNeiA.png"
        )
    return RedirectResponse(
        url="/TeenStudy/login"
    )


@route.post("/beijing/add", response_class=HTMLResponse)
async def beijing_add(data: dict) -> JSONResponse:
    user_id = data["user_id"]
    if await User.filter(user_id=user_id).count():
        return JSONResponse({
            "status": 500,
            "msg": "添加失败！，用户信息存在！"
        })
    else:
        token = data["token"]
        cookie = data["cookie"]
        login_url = "https://m.bjyouth.net/site/login"
        headers = {
            "User-Agent": "Mozilla/5.0 (iPhone; CPU iPhone OS 13_2_3 like Mac OS X) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/13.0.3 Mobile/15E148 Safari/604.1 Edg/113.0.0.0", }
        try:
            async with AsyncClient(headers=headers) as client:
                login_rsp = await client.get(login_url)
                if login_rsp.status_code == 200:
                    login_rsp.encoding = login_rsp.charset_encoding
                    soup = BeautifulSoup(login_rsp.text, "lxml")
                    code_url = "https://m.bjyouth.net" + soup.select("#verifyCode-image")[0].get("src")
                    code_rsp = await client.get(code_url)
                    code_text = DdddOcr(show_ad=False).classification(code_rsp.content)
                    login_response = await client.post(
                        url=login_url,
                        data={
                            '_csrf_mobile': client.cookies['_csrf_mobile'],
                            'Login[password]': await encrypt(token),
                            'Login[username]': await encrypt(cookie),
                            'Login[verifyCode]': code_text
                        }
                    )
                    logger.debug(login_response.text)
                    if login_response.status_code == 200:
                        login_response.encoding = login_response.charset_encoding
                        if login_response.text == '8':
                            return JSONResponse({"status": 500, "msg": "添加失败,验证码错误！"})
                        if 'fail' in login_response.text:
                            return JSONResponse({"status": 500, "msg": "添加失败,账号或密码错误！"})
                        status = await write_to_database(data=data)
                        if status:
                            return JSONResponse(
                                {
                                    "status": 0,
                                    "msg": "添加成功！"
                                }
                            )
                        else:
                            return JSONResponse({
                                "status": 500,
                                "msg": "添加失败！"
                            })
                    else:
                        return JSONResponse({"status": 500, "msg": "添加失败！"})
                else:
                    return JSONResponse({"status": 500, "msg": "添加失败！"})
        except Exception as e:
            return JSONResponse({
                "status": 500,
                "msg": f"# 添加失败,{e}"
            })


@route.get("/beijing", response_class=HTMLResponse)
async def beijing(user_id: int, group_id: int):
    result = await AddUser.filter(user_id=user_id, group_id=group_id, status="未通过").count()
    if result:
        return beijing_page.render(
            site_title='北京共青团 | TeenStudy',
            site_icon="https://img1.imgtp.com/2023/10/06/NChUNeiA.png"
        )
    return RedirectResponse(
        url="/TeenStudy/login"
    )


@route.post("/tianjin/add", response_class=JSONResponse)
async def tianjin_add(data: dict) -> JSONResponse:
    user_id = data["user_id"]
    if await User.filter(user_id=user_id).count():
        return JSONResponse({
            "status": 0,
            "msg": "添加失败！，用户信息存在！"
        })
    else:
        status = await write_to_database(data=data)
        if status:
            return JSONResponse(
                {
                    "status": 0,
                    "msg": "添加成功！"
                }
            )
        else:
            return JSONResponse({
                "status": 500,
                "msg": "添加失败！"
            })


@route.get("/tianjin", response_class=HTMLResponse)
async def tianjin(user_id: int, group_id: int):
    result = await AddUser.filter(user_id=user_id, group_id=group_id, status="未通过").count()
    if result:
        return tianjin_page.render(
            site_title='津彩青春 | TeenStudy',
            site_icon="https://img1.imgtp.com/2023/10/06/NChUNeiA.png"
        )
    return RedirectResponse(
        url="/TeenStudy/login"
    )


@route.post("/shanxi/add", response_class=JSONResponse)
async def shanxi_add(data: dict) -> JSONResponse:
    user_id = data["user_id"]
    if await User.filter(user_id=user_id).count():
        return JSONResponse({
            "status": 0,
            "msg": "添加失败！，用户信息存在！"
        })
    else:
        status = await write_to_database(data=data)
        if status:
            return JSONResponse(
                {
                    "status": 0,
                    "msg": "添加成功！"
                }
            )
        else:
            return JSONResponse({
                "status": 500,
                "msg": "添加失败！"
            })


@route.get("/shanxi", response_class=HTMLResponse)
async def shanxi(user_id: int, group_id: int):
    result = await AddUser.filter(user_id=user_id, group_id=group_id, status="未通过").count()
    if result:
        return shanxi_page.render(
            site_title='三秦青年 | TeenStudy',
            site_icon="https://img1.imgtp.com/2023/10/06/NChUNeiA.png"
        )
    return RedirectResponse(
        url="/TeenStudy/login"
    )



import datetime
from typing import Optional

from fastapi import APIRouter, Header
from fastapi.responses import JSONResponse

from .login import authentication, get_userInfo
from ...models.accuont import User, Commit
from ...models.dxx import Answer
from ...utils.utils import distribute_area
from ...utils.utils import to_hash

route = APIRouter()


@route.get("/get_user", response_class=JSONResponse, dependencies=[authentication()])
async def get_user(token: Optional[str] = Header(...)) -> JSONResponse:
    userinfo = await get_userInfo(token=token)
    user_id = userinfo["user_id"]
    result = await User.filter(user_id=user_id).values()
    if result:
        data = result[0]
        try:
            data["commit_time"] = datetime.datetime.fromtimestamp(data['commit_time']).strftime(
                "%Y-%m-%d %H:%M:%S")
        except TypeError:
            data["commit_time"] = "暂未提交"
        if data["catalogue"] is None:
            data["catalogue"] = "暂未提交"
        return JSONResponse(
            data)


@route.put("/change", response_class=JSONResponse, dependencies=[authentication()])
async def change(user_id: int, data: dict) -> JSONResponse:
    if await User.filter(user_id=user_id).values():
        password = data["Password"]
        if password:
            data["password"] = await to_hash(password)
        data.pop("Password")
        if data["leader"] == "":
            data["leader"] = None
        await User.filter(user_id=user_id).update(**data)
        return JSONResponse({
            "status": 0,
            "msg": "修改成功！"
        })
    else:
        return JSONResponse({
            "status": 422,
            "msg": "用户不存在！"
        })


@route.get("/get_records", response_class=JSONResponse, dependencies=[authentication()])
async def get_records(
        token: Optional[str] = Header(...),
        page: int = 1,
        perPage: int = 10,
        orderBy: str = 'time',
        orderDir: str = 'desc',
        group_id: Optional[str] = None,
        user_id: Optional[str] = None,
        name: Optional[str] = None,
        college: Optional[str] = None,
        organization: Optional[str] = None,
        catalogue: Optional[str] = None,
        status: Optional[str] = None,
        area: Optional[str] = None
) -> JSONResponse:
    userinfo = await get_userInfo(token=token)
    if not user_id:
        if userinfo["role"]:
            user_id = ""
        else:
            user_id = userinfo["user_id"]
    orderBy = (orderBy or 'time') if (orderDir or 'desc') == 'asc' else f'-{orderBy or "time"}'
    filter_args = {f'{k}__contains': v for k, v in
                   {'group_id': group_id, 'user_id': user_id, "area": area, "name": name, "college": college,
                    "organization": organization, "catalogue": catalogue, "status": status}.items() if v}
    return JSONResponse({
        'status': 0,
        'msg': 'ok',
        'data': {
            'items': await Commit.filter(**filter_args).order_by(orderBy).offset((page - 1) * perPage).limit(
                perPage).values(),
            'total': await Commit.filter(**filter_args).count()
        }
    })


@route.get('/get_answers', response_class=JSONResponse, dependencies=[authentication()])
async def get_answers(page: int = 1,
                      perPage: int = 10,
                      orderBy: str = 'time',
                      orderDir: str = 'desc',
                      catalogue: Optional[str] = None
                      ) -> JSONResponse:
    orderBy = (orderBy or 'time') if (orderDir or 'desc') == 'asc' else f'-{orderBy or "time"}'
    filter_args = {f'{k}__contains': v for k, v in
                   {'catalogue': catalogue}.items() if v}
    items = await Answer.filter(**filter_args).order_by(orderBy).offset((page - 1) * perPage).limit(
        perPage).values()
    for item in items:
        item.pop("cover")
    return JSONResponse({
        'status': 0,
        'msg': 'ok',
        'data': {
            'items': items,
            'total': await Answer.filter(**filter_args).count()
        }
    })


@route.get('/commit', response_class=JSONResponse, dependencies=[authentication()])
async def commit(user_id: int, area: str, catalogue: Optional[str] = None) -> JSONResponse:
    data = await distribute_area(user_id=user_id, area=area,catalogue=catalogue)
    return JSONResponse({
        "status": data["status"],
        "msg": data["msg"]
    })


@route.put("/set_auto_submit", response_class=JSONResponse, dependencies=[authentication()])
async def set_auto_submit(data: dict) -> JSONResponse:
    await User.filter(id=data["id"]).update(auto_submit=data["status"])
    return JSONResponse({"status": 0})
